# Generated from APIParser.g4 by ANTLR 4.11.1
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,230,612,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,
        7,6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,2,13,7,
        13,2,14,7,14,2,15,7,15,2,16,7,16,2,17,7,17,2,18,7,18,2,19,7,19,2,
        20,7,20,2,21,7,21,2,22,7,22,2,23,7,23,2,24,7,24,2,25,7,25,2,26,7,
        26,2,27,7,27,2,28,7,28,2,29,7,29,2,30,7,30,2,31,7,31,2,32,7,32,2,
        33,7,33,2,34,7,34,2,35,7,35,2,36,7,36,2,37,7,37,2,38,7,38,2,39,7,
        39,2,40,7,40,1,0,1,0,1,0,1,1,1,1,1,1,3,1,89,8,1,1,2,1,2,5,2,93,8,
        2,10,2,12,2,96,9,2,1,2,1,2,1,2,1,3,1,3,1,3,3,3,104,8,3,1,4,1,4,1,
        4,1,5,1,5,1,6,1,6,1,7,5,7,114,8,7,10,7,12,7,117,9,7,1,8,1,8,1,8,
        1,8,1,9,1,9,1,10,1,10,1,10,1,11,1,11,4,11,130,8,11,11,11,12,11,131,
        1,12,4,12,135,8,12,11,12,12,12,136,1,12,1,12,1,13,1,13,1,13,1,13,
        1,14,1,14,1,15,1,15,4,15,149,8,15,11,15,12,15,150,1,16,1,16,1,17,
        4,17,156,8,17,11,17,12,17,157,1,18,1,18,1,18,1,18,1,18,1,18,1,18,
        1,18,1,18,1,18,1,18,1,18,1,18,1,18,1,18,1,18,1,18,1,18,1,18,1,18,
        1,18,1,18,3,18,182,8,18,1,19,1,19,3,19,186,8,19,1,19,3,19,189,8,
        19,1,19,3,19,192,8,19,1,20,1,20,3,20,196,8,20,1,20,3,20,199,8,20,
        1,20,3,20,202,8,20,1,21,1,21,1,21,3,21,207,8,21,1,21,3,21,210,8,
        21,1,22,1,22,1,22,3,22,215,8,22,1,22,3,22,218,8,22,1,23,1,23,4,23,
        222,8,23,11,23,12,23,223,1,23,3,23,227,8,23,1,23,3,23,230,8,23,1,
        24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,1,
        24,1,24,1,24,1,24,1,24,1,24,1,24,1,24,5,24,253,8,24,10,24,12,24,
        256,9,24,3,24,258,8,24,1,24,3,24,261,8,24,1,24,3,24,264,8,24,1,25,
        1,25,1,25,3,25,269,8,25,1,25,3,25,272,8,25,1,25,3,25,275,8,25,1,
        25,3,25,278,8,25,1,26,1,26,1,26,3,26,283,8,26,1,26,3,26,286,8,26,
        1,27,1,27,1,27,1,27,1,27,1,27,1,27,3,27,295,8,27,1,27,3,27,298,8,
        27,1,27,3,27,301,8,27,1,28,1,28,1,28,3,28,306,8,28,1,28,3,28,309,
        8,28,1,29,1,29,3,29,313,8,29,1,29,3,29,316,8,29,1,30,1,30,1,30,1,
        30,1,30,3,30,323,8,30,1,30,3,30,326,8,30,1,30,3,30,329,8,30,1,31,
        1,31,1,31,3,31,334,8,31,1,31,3,31,337,8,31,1,32,1,32,1,32,3,32,342,
        8,32,1,33,1,33,1,33,3,33,347,8,33,1,34,1,34,5,34,351,8,34,10,34,
        12,34,354,9,34,1,34,3,34,357,8,34,1,34,3,34,360,8,34,1,35,1,35,1,
        35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,3,
        35,377,8,35,1,35,1,35,4,35,381,8,35,11,35,12,35,382,1,35,1,35,1,
        35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,
        35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,35,1,
        35,1,35,1,35,1,35,1,35,1,35,1,35,3,35,420,8,35,3,35,422,8,35,1,35,
        3,35,425,8,35,1,35,3,35,428,8,35,1,36,1,36,1,36,1,36,1,36,1,36,1,
        36,1,36,1,36,1,36,1,36,1,36,1,36,1,36,1,36,1,36,1,36,1,36,1,36,1,
        36,1,36,1,36,1,36,1,36,1,36,1,36,4,36,456,8,36,11,36,12,36,457,1,
        36,1,36,1,36,1,36,1,36,5,36,465,8,36,10,36,12,36,468,9,36,3,36,470,
        8,36,1,36,3,36,473,8,36,1,36,3,36,476,8,36,1,37,1,37,1,37,1,37,5,
        37,482,8,37,10,37,12,37,485,9,37,1,37,1,37,1,37,1,37,1,37,1,37,1,
        37,1,37,1,37,1,37,1,37,5,37,498,8,37,10,37,12,37,501,9,37,1,37,1,
        37,1,37,4,37,506,8,37,11,37,12,37,507,1,37,1,37,1,37,1,37,1,37,1,
        37,1,37,3,37,517,8,37,1,37,3,37,520,8,37,1,37,3,37,523,8,37,1,38,
        1,38,1,38,1,38,1,38,1,38,3,38,531,8,38,1,38,1,38,1,38,1,38,1,38,
        1,38,3,38,539,8,38,1,38,1,38,3,38,543,8,38,1,38,1,38,1,38,1,38,1,
        38,1,38,1,38,1,38,1,38,1,38,3,38,555,8,38,3,38,557,8,38,1,38,3,38,
        560,8,38,1,39,1,39,3,39,564,8,39,1,39,3,39,567,8,39,1,39,3,39,570,
        8,39,1,40,1,40,1,40,1,40,1,40,3,40,577,8,40,1,40,1,40,1,40,1,40,
        1,40,3,40,584,8,40,1,40,1,40,1,40,4,40,589,8,40,11,40,12,40,590,
        1,40,1,40,1,40,1,40,1,40,1,40,1,40,1,40,1,40,1,40,1,40,3,40,604,
        8,40,1,40,3,40,607,8,40,1,40,3,40,610,8,40,1,40,0,0,41,0,2,4,6,8,
        10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,
        54,56,58,60,62,64,66,68,70,72,74,76,78,80,0,10,1,1,48,48,2,0,4,4,
        43,43,1,0,114,115,1,1,4,4,1,0,161,162,2,0,171,172,175,180,1,0,184,
        185,1,0,182,183,1,0,191,192,1,0,189,190,717,0,82,1,0,0,0,2,88,1,
        0,0,0,4,90,1,0,0,0,6,100,1,0,0,0,8,105,1,0,0,0,10,108,1,0,0,0,12,
        110,1,0,0,0,14,115,1,0,0,0,16,118,1,0,0,0,18,122,1,0,0,0,20,124,
        1,0,0,0,22,129,1,0,0,0,24,134,1,0,0,0,26,140,1,0,0,0,28,144,1,0,
        0,0,30,148,1,0,0,0,32,152,1,0,0,0,34,155,1,0,0,0,36,181,1,0,0,0,
        38,183,1,0,0,0,40,193,1,0,0,0,42,203,1,0,0,0,44,211,1,0,0,0,46,219,
        1,0,0,0,48,231,1,0,0,0,50,265,1,0,0,0,52,279,1,0,0,0,54,287,1,0,
        0,0,56,302,1,0,0,0,58,310,1,0,0,0,60,317,1,0,0,0,62,330,1,0,0,0,
        64,338,1,0,0,0,66,343,1,0,0,0,68,348,1,0,0,0,70,361,1,0,0,0,72,429,
        1,0,0,0,74,477,1,0,0,0,76,524,1,0,0,0,78,561,1,0,0,0,80,571,1,0,
        0,0,82,83,3,2,1,0,83,84,5,0,0,1,84,1,1,0,0,0,85,89,3,36,18,0,86,
        89,3,4,2,0,87,89,5,0,0,1,88,85,1,0,0,0,88,86,1,0,0,0,88,87,1,0,0,
        0,89,3,1,0,0,0,90,94,5,1,0,0,91,93,5,4,0,0,92,91,1,0,0,0,93,96,1,
        0,0,0,94,92,1,0,0,0,94,95,1,0,0,0,95,97,1,0,0,0,96,94,1,0,0,0,97,
        98,3,6,3,0,98,99,7,0,0,0,99,5,1,0,0,0,100,101,3,8,4,0,101,103,3,
        14,7,0,102,104,3,22,11,0,103,102,1,0,0,0,103,104,1,0,0,0,104,7,1,
        0,0,0,105,106,3,10,5,0,106,107,3,12,6,0,107,9,1,0,0,0,108,109,5,
        47,0,0,109,11,1,0,0,0,110,111,5,49,0,0,111,13,1,0,0,0,112,114,3,
        16,8,0,113,112,1,0,0,0,114,117,1,0,0,0,115,113,1,0,0,0,115,116,1,
        0,0,0,116,15,1,0,0,0,117,115,1,0,0,0,118,119,3,18,9,0,119,120,5,
        51,0,0,120,121,3,20,10,0,121,17,1,0,0,0,122,123,5,50,0,0,123,19,
        1,0,0,0,124,125,5,53,0,0,125,126,5,54,0,0,126,21,1,0,0,0,127,130,
        3,24,12,0,128,130,3,30,15,0,129,127,1,0,0,0,129,128,1,0,0,0,130,
        131,1,0,0,0,131,129,1,0,0,0,131,132,1,0,0,0,132,23,1,0,0,0,133,135,
        3,26,13,0,134,133,1,0,0,0,135,136,1,0,0,0,136,134,1,0,0,0,136,137,
        1,0,0,0,137,138,1,0,0,0,138,139,5,55,0,0,139,25,1,0,0,0,140,141,
        3,28,14,0,141,142,3,14,7,0,142,143,3,30,15,0,143,27,1,0,0,0,144,
        145,5,56,0,0,145,29,1,0,0,0,146,149,3,32,16,0,147,149,3,34,17,0,
        148,146,1,0,0,0,148,147,1,0,0,0,149,150,1,0,0,0,150,148,1,0,0,0,
        150,151,1,0,0,0,151,31,1,0,0,0,152,153,5,58,0,0,153,33,1,0,0,0,154,
        156,7,1,0,0,155,154,1,0,0,0,156,157,1,0,0,0,157,155,1,0,0,0,157,
        158,1,0,0,0,158,35,1,0,0,0,159,182,3,50,25,0,160,182,3,48,24,0,161,
        182,3,52,26,0,162,182,3,46,23,0,163,182,3,54,27,0,164,182,3,56,28,
        0,165,182,3,58,29,0,166,182,3,60,30,0,167,182,3,68,34,0,168,182,
        3,42,21,0,169,182,3,38,19,0,170,182,3,40,20,0,171,182,3,44,22,0,
        172,182,3,62,31,0,173,182,3,66,33,0,174,182,3,64,32,0,175,182,3,
        70,35,0,176,182,3,72,36,0,177,182,3,74,37,0,178,182,3,76,38,0,179,
        182,3,78,39,0,180,182,3,80,40,0,181,159,1,0,0,0,181,160,1,0,0,0,
        181,161,1,0,0,0,181,162,1,0,0,0,181,163,1,0,0,0,181,164,1,0,0,0,
        181,165,1,0,0,0,181,166,1,0,0,0,181,167,1,0,0,0,181,168,1,0,0,0,
        181,169,1,0,0,0,181,170,1,0,0,0,181,171,1,0,0,0,181,172,1,0,0,0,
        181,173,1,0,0,0,181,174,1,0,0,0,181,175,1,0,0,0,181,176,1,0,0,0,
        181,177,1,0,0,0,181,178,1,0,0,0,181,179,1,0,0,0,181,180,1,0,0,0,
        182,37,1,0,0,0,183,185,5,19,0,0,184,186,5,41,0,0,185,184,1,0,0,0,
        185,186,1,0,0,0,186,188,1,0,0,0,187,189,5,6,0,0,188,187,1,0,0,0,
        188,189,1,0,0,0,189,191,1,0,0,0,190,192,5,4,0,0,191,190,1,0,0,0,
        191,192,1,0,0,0,192,39,1,0,0,0,193,195,5,20,0,0,194,196,5,41,0,0,
        195,194,1,0,0,0,195,196,1,0,0,0,196,198,1,0,0,0,197,199,5,6,0,0,
        198,197,1,0,0,0,198,199,1,0,0,0,199,201,1,0,0,0,200,202,5,4,0,0,
        201,200,1,0,0,0,201,202,1,0,0,0,202,41,1,0,0,0,203,204,5,23,0,0,
        204,206,7,2,0,0,205,207,5,117,0,0,206,205,1,0,0,0,206,207,1,0,0,
        0,207,209,1,0,0,0,208,210,5,4,0,0,209,208,1,0,0,0,209,210,1,0,0,
        0,210,43,1,0,0,0,211,212,5,22,0,0,212,214,5,41,0,0,213,215,5,6,0,
        0,214,213,1,0,0,0,214,215,1,0,0,0,215,217,1,0,0,0,216,218,5,4,0,
        0,217,216,1,0,0,0,217,218,1,0,0,0,218,45,1,0,0,0,219,221,5,27,0,
        0,220,222,5,83,0,0,221,220,1,0,0,0,222,223,1,0,0,0,223,221,1,0,0,
        0,223,224,1,0,0,0,224,226,1,0,0,0,225,227,5,6,0,0,226,225,1,0,0,
        0,226,227,1,0,0,0,227,229,1,0,0,0,228,230,5,4,0,0,229,228,1,0,0,
        0,229,230,1,0,0,0,230,47,1,0,0,0,231,257,5,28,0,0,232,233,5,71,0,
        0,233,258,5,79,0,0,234,235,5,72,0,0,235,258,5,79,0,0,236,254,5,73,
        0,0,237,238,5,75,0,0,238,239,5,70,0,0,239,253,5,79,0,0,240,241,5,
        74,0,0,241,242,5,70,0,0,242,253,5,79,0,0,243,244,5,76,0,0,244,245,
        5,70,0,0,245,253,5,79,0,0,246,247,5,77,0,0,247,248,5,70,0,0,248,
        253,5,79,0,0,249,250,5,78,0,0,250,251,5,70,0,0,251,253,5,79,0,0,
        252,237,1,0,0,0,252,240,1,0,0,0,252,243,1,0,0,0,252,246,1,0,0,0,
        252,249,1,0,0,0,253,256,1,0,0,0,254,252,1,0,0,0,254,255,1,0,0,0,
        255,258,1,0,0,0,256,254,1,0,0,0,257,232,1,0,0,0,257,234,1,0,0,0,
        257,236,1,0,0,0,258,260,1,0,0,0,259,261,5,80,0,0,260,259,1,0,0,0,
        260,261,1,0,0,0,261,263,1,0,0,0,262,264,5,4,0,0,263,262,1,0,0,0,
        263,264,1,0,0,0,264,49,1,0,0,0,265,266,5,26,0,0,266,271,5,65,0,0,
        267,269,5,67,0,0,268,267,1,0,0,0,268,269,1,0,0,0,269,270,1,0,0,0,
        270,272,5,66,0,0,271,268,1,0,0,0,271,272,1,0,0,0,272,274,1,0,0,0,
        273,275,5,68,0,0,274,273,1,0,0,0,274,275,1,0,0,0,275,277,1,0,0,0,
        276,278,5,4,0,0,277,276,1,0,0,0,277,278,1,0,0,0,278,51,1,0,0,0,279,
        280,5,29,0,0,280,282,5,86,0,0,281,283,5,6,0,0,282,281,1,0,0,0,282,
        283,1,0,0,0,283,285,1,0,0,0,284,286,5,4,0,0,285,284,1,0,0,0,285,
        286,1,0,0,0,286,53,1,0,0,0,287,294,5,34,0,0,288,295,5,98,0,0,289,
        295,5,99,0,0,290,295,5,100,0,0,291,292,5,94,0,0,292,293,5,95,0,0,
        293,295,5,101,0,0,294,288,1,0,0,0,294,289,1,0,0,0,294,290,1,0,0,
        0,294,291,1,0,0,0,295,297,1,0,0,0,296,298,5,92,0,0,297,296,1,0,0,
        0,297,298,1,0,0,0,298,300,1,0,0,0,299,301,5,4,0,0,300,299,1,0,0,
        0,300,301,1,0,0,0,301,55,1,0,0,0,302,303,5,31,0,0,303,305,5,91,0,
        0,304,306,5,6,0,0,305,304,1,0,0,0,305,306,1,0,0,0,306,308,1,0,0,
        0,307,309,5,4,0,0,308,307,1,0,0,0,308,309,1,0,0,0,309,57,1,0,0,0,
        310,312,5,32,0,0,311,313,5,6,0,0,312,311,1,0,0,0,312,313,1,0,0,0,
        313,315,1,0,0,0,314,316,5,4,0,0,315,314,1,0,0,0,315,316,1,0,0,0,
        316,59,1,0,0,0,317,318,5,35,0,0,318,322,5,105,0,0,319,323,5,107,
        0,0,320,321,5,108,0,0,321,323,5,104,0,0,322,319,1,0,0,0,322,320,
        1,0,0,0,323,325,1,0,0,0,324,326,5,106,0,0,325,324,1,0,0,0,325,326,
        1,0,0,0,326,328,1,0,0,0,327,329,5,4,0,0,328,327,1,0,0,0,328,329,
        1,0,0,0,329,61,1,0,0,0,330,331,5,21,0,0,331,333,5,43,0,0,332,334,
        5,6,0,0,333,332,1,0,0,0,333,334,1,0,0,0,334,336,1,0,0,0,335,337,
        5,4,0,0,336,335,1,0,0,0,336,337,1,0,0,0,337,63,1,0,0,0,338,339,5,
        24,0,0,339,341,5,60,0,0,340,342,7,3,0,0,341,340,1,0,0,0,341,342,
        1,0,0,0,342,65,1,0,0,0,343,344,5,25,0,0,344,346,5,59,0,0,345,347,
        5,4,0,0,346,345,1,0,0,0,346,347,1,0,0,0,347,67,1,0,0,0,348,352,5,
        33,0,0,349,351,5,111,0,0,350,349,1,0,0,0,351,354,1,0,0,0,352,350,
        1,0,0,0,352,353,1,0,0,0,353,356,1,0,0,0,354,352,1,0,0,0,355,357,
        5,112,0,0,356,355,1,0,0,0,356,357,1,0,0,0,357,359,1,0,0,0,358,360,
        5,4,0,0,359,358,1,0,0,0,359,360,1,0,0,0,360,69,1,0,0,0,361,421,5,
        36,0,0,362,363,5,119,0,0,363,364,5,144,0,0,364,365,5,120,0,0,365,
        366,5,121,0,0,366,367,5,144,0,0,367,368,5,122,0,0,368,422,5,144,
        0,0,369,370,5,119,0,0,370,371,5,144,0,0,371,372,5,120,0,0,372,373,
        5,121,0,0,373,376,5,144,0,0,374,375,5,123,0,0,375,377,5,144,0,0,
        376,374,1,0,0,0,376,377,1,0,0,0,377,422,1,0,0,0,378,380,5,124,0,
        0,379,381,5,144,0,0,380,379,1,0,0,0,381,382,1,0,0,0,382,380,1,0,
        0,0,382,383,1,0,0,0,383,422,1,0,0,0,384,422,5,125,0,0,385,386,5,
        126,0,0,386,422,5,144,0,0,387,388,5,127,0,0,388,422,5,144,0,0,389,
        419,5,129,0,0,390,391,5,130,0,0,391,392,5,144,0,0,392,420,5,128,
        0,0,393,420,5,131,0,0,394,395,5,132,0,0,395,420,5,144,0,0,396,397,
        5,133,0,0,397,398,5,144,0,0,398,399,5,128,0,0,399,420,5,128,0,0,
        400,401,5,134,0,0,401,402,5,144,0,0,402,420,5,128,0,0,403,404,5,
        135,0,0,404,405,5,144,0,0,405,420,5,144,0,0,406,407,5,136,0,0,407,
        408,5,144,0,0,408,420,5,144,0,0,409,410,5,137,0,0,410,420,5,144,
        0,0,411,412,5,138,0,0,412,413,5,144,0,0,413,420,5,144,0,0,414,415,
        5,139,0,0,415,420,5,144,0,0,416,417,5,140,0,0,417,418,5,144,0,0,
        418,420,5,128,0,0,419,390,1,0,0,0,419,393,1,0,0,0,419,394,1,0,0,
        0,419,396,1,0,0,0,419,400,1,0,0,0,419,403,1,0,0,0,419,406,1,0,0,
        0,419,409,1,0,0,0,419,411,1,0,0,0,419,414,1,0,0,0,419,416,1,0,0,
        0,420,422,1,0,0,0,421,362,1,0,0,0,421,369,1,0,0,0,421,378,1,0,0,
        0,421,384,1,0,0,0,421,385,1,0,0,0,421,387,1,0,0,0,421,389,1,0,0,
        0,422,424,1,0,0,0,423,425,5,142,0,0,424,423,1,0,0,0,424,425,1,0,
        0,0,425,427,1,0,0,0,426,428,5,4,0,0,427,426,1,0,0,0,427,428,1,0,
        0,0,428,71,1,0,0,0,429,469,5,37,0,0,430,431,5,160,0,0,431,470,7,
        4,0,0,432,433,5,153,0,0,433,470,5,164,0,0,434,435,5,150,0,0,435,
        470,5,164,0,0,436,437,5,155,0,0,437,470,5,164,0,0,438,439,5,154,
        0,0,439,470,5,164,0,0,440,441,5,156,0,0,441,470,5,164,0,0,442,443,
        5,152,0,0,443,470,5,164,0,0,444,445,5,158,0,0,445,470,5,159,0,0,
        446,447,5,157,0,0,447,448,5,159,0,0,448,449,5,163,0,0,449,470,5,
        164,0,0,450,451,5,151,0,0,451,455,5,164,0,0,452,453,5,164,0,0,453,
        454,5,147,0,0,454,456,5,164,0,0,455,452,1,0,0,0,456,457,1,0,0,0,
        457,455,1,0,0,0,457,458,1,0,0,0,458,470,1,0,0,0,459,460,5,149,0,
        0,460,466,5,164,0,0,461,462,5,164,0,0,462,463,5,147,0,0,463,465,
        5,164,0,0,464,461,1,0,0,0,465,468,1,0,0,0,466,464,1,0,0,0,466,467,
        1,0,0,0,467,470,1,0,0,0,468,466,1,0,0,0,469,430,1,0,0,0,469,432,
        1,0,0,0,469,434,1,0,0,0,469,436,1,0,0,0,469,438,1,0,0,0,469,440,
        1,0,0,0,469,442,1,0,0,0,469,444,1,0,0,0,469,446,1,0,0,0,469,450,
        1,0,0,0,469,459,1,0,0,0,470,472,1,0,0,0,471,473,5,146,0,0,472,471,
        1,0,0,0,472,473,1,0,0,0,473,475,1,0,0,0,474,476,5,4,0,0,475,474,
        1,0,0,0,475,476,1,0,0,0,476,73,1,0,0,0,477,516,5,38,0,0,478,479,
        5,193,0,0,479,483,5,193,0,0,480,482,7,5,0,0,481,480,1,0,0,0,482,
        485,1,0,0,0,483,481,1,0,0,0,483,484,1,0,0,0,484,517,1,0,0,0,485,
        483,1,0,0,0,486,487,7,6,0,0,487,517,5,193,0,0,488,489,5,173,0,0,
        489,490,5,193,0,0,490,491,5,167,0,0,491,517,5,193,0,0,492,493,5,
        174,0,0,493,517,5,193,0,0,494,517,5,186,0,0,495,499,5,169,0,0,496,
        498,7,5,0,0,497,496,1,0,0,0,498,501,1,0,0,0,499,497,1,0,0,0,499,
        500,1,0,0,0,500,517,1,0,0,0,501,499,1,0,0,0,502,503,5,169,0,0,503,
        505,5,181,0,0,504,506,7,7,0,0,505,504,1,0,0,0,506,507,1,0,0,0,507,
        505,1,0,0,0,507,508,1,0,0,0,508,517,1,0,0,0,509,510,5,169,0,0,510,
        511,5,187,0,0,511,517,7,8,0,0,512,513,5,169,0,0,513,514,7,9,0,0,
        514,515,5,188,0,0,515,517,5,193,0,0,516,478,1,0,0,0,516,486,1,0,
        0,0,516,488,1,0,0,0,516,492,1,0,0,0,516,494,1,0,0,0,516,495,1,0,
        0,0,516,502,1,0,0,0,516,509,1,0,0,0,516,512,1,0,0,0,517,519,1,0,
        0,0,518,520,5,166,0,0,519,518,1,0,0,0,519,520,1,0,0,0,520,522,1,
        0,0,0,521,523,5,4,0,0,522,521,1,0,0,0,522,523,1,0,0,0,523,75,1,0,
        0,0,524,556,5,39,0,0,525,526,5,196,0,0,526,527,5,197,0,0,527,528,
        5,198,0,0,528,530,5,208,0,0,529,531,5,195,0,0,530,529,1,0,0,0,530,
        531,1,0,0,0,531,557,1,0,0,0,532,533,5,199,0,0,533,534,5,201,0,0,
        534,535,5,200,0,0,535,536,5,208,0,0,536,538,5,205,0,0,537,539,5,
        211,0,0,538,537,1,0,0,0,538,539,1,0,0,0,539,542,1,0,0,0,540,541,
        5,202,0,0,541,543,5,203,0,0,542,540,1,0,0,0,542,543,1,0,0,0,543,
        544,1,0,0,0,544,557,5,195,0,0,545,546,5,206,0,0,546,547,5,201,0,
        0,547,548,5,200,0,0,548,549,5,208,0,0,549,550,5,207,0,0,550,551,
        5,201,0,0,551,552,5,200,0,0,552,554,5,208,0,0,553,555,5,195,0,0,
        554,553,1,0,0,0,554,555,1,0,0,0,555,557,1,0,0,0,556,525,1,0,0,0,
        556,532,1,0,0,0,556,545,1,0,0,0,557,559,1,0,0,0,558,560,5,4,0,0,
        559,558,1,0,0,0,559,560,1,0,0,0,560,77,1,0,0,0,561,563,5,30,0,0,
        562,564,5,213,0,0,563,562,1,0,0,0,563,564,1,0,0,0,564,566,1,0,0,
        0,565,567,5,215,0,0,566,565,1,0,0,0,566,567,1,0,0,0,567,569,1,0,
        0,0,568,570,5,4,0,0,569,568,1,0,0,0,569,570,1,0,0,0,570,79,1,0,0,
        0,571,603,5,40,0,0,572,573,5,217,0,0,573,576,5,226,0,0,574,575,5,
        218,0,0,575,577,5,228,0,0,576,574,1,0,0,0,576,577,1,0,0,0,577,604,
        1,0,0,0,578,579,5,217,0,0,579,604,5,227,0,0,580,581,5,219,0,0,581,
        583,5,220,0,0,582,584,5,228,0,0,583,582,1,0,0,0,583,584,1,0,0,0,
        584,588,1,0,0,0,585,586,5,228,0,0,586,587,5,221,0,0,587,589,5,228,
        0,0,588,585,1,0,0,0,589,590,1,0,0,0,590,588,1,0,0,0,590,591,1,0,
        0,0,591,604,1,0,0,0,592,593,5,222,0,0,593,594,5,220,0,0,594,604,
        5,228,0,0,595,596,5,223,0,0,596,597,5,220,0,0,597,604,5,228,0,0,
        598,599,5,224,0,0,599,600,5,220,0,0,600,604,5,228,0,0,601,602,5,
        225,0,0,602,604,5,220,0,0,603,572,1,0,0,0,603,578,1,0,0,0,603,580,
        1,0,0,0,603,592,1,0,0,0,603,595,1,0,0,0,603,598,1,0,0,0,603,601,
        1,0,0,0,604,606,1,0,0,0,605,607,5,230,0,0,606,605,1,0,0,0,606,607,
        1,0,0,0,607,609,1,0,0,0,608,610,5,229,0,0,609,608,1,0,0,0,609,610,
        1,0,0,0,610,81,1,0,0,0,84,88,94,103,115,129,131,136,148,150,157,
        181,185,188,191,195,198,201,206,209,214,217,223,226,229,252,254,
        257,260,263,268,271,274,277,282,285,294,297,300,305,308,312,315,
        322,325,328,333,336,341,346,352,356,359,376,382,419,421,424,427,
        457,466,469,472,475,483,499,507,516,519,522,530,538,542,554,556,
        559,563,566,569,576,583,590,603,606,609
    ]

class APIParser ( Parser ):

    grammarFileName = "APIParser.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'@'", "'.'", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'['", "']'", "'\"'", "'''", "'\\'", "<INVALID>", "'_EXIT'", 
                     "'_QUIT'", "'_SPOOL'", "'_SLEEP'", "'_USE'", "<INVALID>", 
                     "'> {%'", "'_ASSERT'", "'_START'", "'_LOAD'", "'_HOST'", 
                     "'_HELP'", "'_IF'", "'_ENDIF'", "'_SET'", "'_LOOP'", 
                     "'_WHENEVER'", "'_SSH'", "'_JOB'", "'_COMPARE'", "'_DATA'", 
                     "'_MONITOR'", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'###'", "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "'PLUGIN'", "'MAP'", "'JDBCDRIVER'", 
                     "<INVALID>", "'CLASS'", "'NAME'", "'PROPS'", "'URL'", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "'BEGIN'", "'UNTIL'", 
                     "<INVALID>", "<INVALID>", "'BREAK'", "'END'", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'ERROR'", "<INVALID>", "<INVALID>", "'EXIT'", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'API'", "'SQL'", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'CONNECT'", "'WITH'", "'USER'", "'KEYFILE'", "'PASSWORD'", 
                     "'EXECUTE'", "'DISCONNECT'", "'SAVE'", "'RESTORE'", 
                     "<INVALID>", "'SFTP'", "'CHMOD'", "'GETCWD'", "'CHDIR'", 
                     "'CHOWN'", "'MKDIR'", "'GET'", "'PUT'", "'REMOVE'", 
                     "'RENAME'", "'LISTDIR'", "'TRUNCATE'", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'SHOW'", "<INVALID>", "<INVALID>", "'WAIT'", "'SHUTDOWN'", 
                     "'ABORT'", "'TIMER'", "'REGISTER'", "'DEREGISTER'", 
                     "'WORKER'", "'JOBMANAGER'", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'=>'", "<INVALID>", "<INVALID>", "'UNSET'", "'MASK'", 
                     "'NOMASK'", "'MASKLINE'", "'NOMASKLINE'", "'CASE'", 
                     "'NOCASE'", "'IGBLANK'", "'NOIGBLANK'", "'TRIM'", "'NOTRIM'", 
                     "'OUTPUT'", "'CONSOLE'", "'DIFFFILE'", "'SKIPLINE'", 
                     "'NOSKIPLINE'", "'RESET'", "'ALGORITHM'", "'ENCODING'", 
                     "'WORK'", "'REFERENCE'", "'LCS'", "'MYERS'", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "'SEEDFILE'", 
                     "'DIR'", "<INVALID>", "<INVALID>", "<INVALID>", "'ROWS'", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "'CONVERT'", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "'MONITORMANAGER'", "'WORKERS'", 
                     "<INVALID>", "'TASK'", "<INVALID>", "<INVALID>", "'STOP'", 
                     "'REPORT'", "'LIST'" ]

    symbolicNames = [ "<INVALID>", "HTTP_OPEN", "COMMENT1", "COMMENT2", 
                      "CRLF", "COMMA", "SEMICOLON", "COLON", "AT", "DOT", 
                      "SLASH", "BRACKET_OPEN", "BRACKET_CLOSE", "SQUARE_OPEN", 
                      "SQUARE_CLOSE", "DOUBLE_QUOTE", "SINGLE_QUOTE", "ESCAPE", 
                      "SPACE", "EXIT", "QUIT", "SPOOL", "SLEEP", "USE", 
                      "ECHO", "SCRIPT", "ASSERT", "START", "LOAD", "HOST", 
                      "HELP", "IF", "ENDIF", "SET", "LOOP", "WHENEVER", 
                      "SSH", "JOB", "COMPARE", "DATA", "MONITOR", "INT", 
                      "DECIMAL", "String", "HTTP_COMMENT", "DIVIDE", "SP", 
                      "HttpMethod", "HTTP_CLOSE", "HttpRequestTarget", "HttpHeaderFieldName", 
                      "FIELD_COLON", "FIELD_CRLF", "HttpHeaderFieldValue", 
                      "HttpHeaderFieldValueEnd", "HttpMultipartBoundaryEnd", 
                      "HttpMultipartBoundary", "HttpMessageBodyComment", 
                      "HttpMessageBodyOperate", "ScriptBlock", "EchoBlock", 
                      "ASSERT_SPACE", "ASSERT_OPEN", "ASSERT_CLOSE", "ASSERT_CRLF", 
                      "ASSERT_EXPRESSION", "ASSERT_NAME", "ASSERT_COMMA", 
                      "ASSERT_SEMICOLON", "LOAD_SPACE", "LOAD_EQUAL", "LOAD_PLUGIN", 
                      "LOAD_MAP", "LOAD_JDBCDRIVER", "LOAD_JDBCFILE", "LOAD_JDBCCLASS", 
                      "LOAD_JDBCNAME", "LOAD_JDBCPROP", "LOAD_JDBCURL", 
                      "LOAD_EXPRESSION", "LOAD_SEMICOLON", "LOAD_CRLF", 
                      "START_SPACE", "START_EXPRESSION", "START_CRLF", "HOST_SPACE", 
                      "HOST_EXPRESSION", "HOST_CRLF", "IF_SPACE", "IF_OPEN", 
                      "IF_CLOSE", "IF_EXPRESSION", "LOOP_SEMICOLON", "LOOP_SPACE", 
                      "LOOP_BEGIN", "LOOP_UNTIL", "LOOP_OPEN", "LOOP_CLOSE", 
                      "LOOP_BREAK", "LOOP_END", "LOOP_CONTINUE", "LOOP_EXPRESSION", 
                      "LOOP_CRLF", "WHENEVER_SPACE", "WHENEVER_EXITCODE", 
                      "WHENEVER_ERROR", "WHENEVER_SEMICOLON", "WHENEVER_CONTINUE", 
                      "WHENEVER_EXIT", "WHENEVER_CRLF", "SET_SPACE", "SET_EXPRESSION", 
                      "SET_SEMICOLON", "SET_CRLF", "USE_API", "USE_SQL", 
                      "USE_SPACE", "USE_SEMICOLON", "USE_CRLF", "SSH_CONNECT", 
                      "SSH_WITH", "SSH_USER", "SSH_KEYFILE", "SSH_PASSWORD", 
                      "SSH_EXECUTE", "SSH_DISCONNECT", "SSH_SAVE", "SSH_RESTORE", 
                      "SSH_INT", "SFTP", "SFTP_CHMOD", "SFTP_GETCWD", "SFTP_CHDIR", 
                      "SFTP_CHOWN", "SFTP_MKDIR", "SFTP_GET", "SFTP_PUT", 
                      "SFTP_REMOVE", "SFTP_RENAME", "SFTP_LISTDIR", "SFTP_TRUNCATE", 
                      "SSH_SPACE", "SSH_SEMICOLON", "SSH_CRLF", "SSH_EXPRESSION", 
                      "JOB_SPACE", "JOB_SEMICOLON", "JOB_EQUAL", "JOB_CRLF", 
                      "JOB_CREATE", "JOB_SHOW", "JOB_SET", "JOB_START", 
                      "JOB_WAIT", "JOB_SHUTDOWN", "JOB_ABORT", "JOB_TIMER", 
                      "JOB_REGISTER", "JOB_DEREGISTER", "JOB_WORKER", "JOB_MANGER", 
                      "JOB_ON", "JOB_OFF", "JOB_TO", "JOB_EXPRESSION", "COMPARE_SPACE", 
                      "COMPARE_SEMICOLON", "COMPARE_EQUAL", "COMPARE_CRLF", 
                      "COMPARE_SET", "COMPARE_UNSET", "COMPARE_MASK", "COMPARE_NOMASK", 
                      "COMPARE_MASKLINE", "COMPARE_NOMASKLINE", "COMPARE_CASE", 
                      "COMPARE_NOCASE", "COMPARE_IGBLANK", "COMPARE_NOIGBLANK", 
                      "COMPARE_TRIM", "COMPARE_NOTRIM", "COMPARE_OUTPUT", 
                      "COMPARE_CONSOLE", "COMPARE_DIFFFILE", "COMPARE_SKIPLINE", 
                      "COMPARE_NOSKIPLINE", "COMPARE_RESET", "COMPARE_ALGORITHM", 
                      "COMPARE_ENCODING", "COMPARE_WORK", "COMPARE_REFERENCE", 
                      "COMPARE_LCS", "COMPARE_MYERS", "COMPARE_EXPRESSION", 
                      "DATA_SPACE", "DATA_SEMICOLON", "DATA_SET", "DATA_SEEDFILE", 
                      "DATA_DIR", "DATA_CREATE", "DATA_FILE", "DATA_FILETYPE", 
                      "DATA_ROWS", "DATA_INT", "DATA_COMMA", "DATACOLUMN_OPEN", 
                      "DATA_CONVERT", "DATA_TO", "DATA_EXPRESSION", "DATACOLUMN_SPACE", 
                      "DATACOLUMN_CLOSE", "DATACOLUMN_CONTENT", "HELP_SPACE", 
                      "HELP_COMMAND", "HELP_CRLF", "HELP_SEMICOLON", "MONITOR_SPACE", 
                      "MONITOR_MANAGER", "MONITOR_WORKERS", "MONITOR_CREATE", 
                      "MONITOR_TASK", "MONITOR_EQUAL", "MONITOR_START", 
                      "MONITOR_STOP", "MONITOR_REPORT", "MONITOR_LIST", 
                      "MONITOR_ON", "MONITOR_OFF", "MONITOR_EXPRESSION", 
                      "MONITOR_CRLF", "MONITOR_SEMICOLON" ]

    RULE_prog = 0
    RULE_command = 1
    RULE_http = 2
    RULE_httpMessage = 3
    RULE_httpRequestLine = 4
    RULE_httpMethod = 5
    RULE_httpRequestTarget = 6
    RULE_httpHeaderFields = 7
    RULE_httpHeaderField = 8
    RULE_httpHeaderFieldName = 9
    RULE_httpHeaderFieldValue = 10
    RULE_httpMessageBody = 11
    RULE_httpMultipart = 12
    RULE_httpMultipartBoundary = 13
    RULE_httpBoundaryDelimiter = 14
    RULE_httpMessageBodyContent = 15
    RULE_httpMessageBodyOperate = 16
    RULE_httpMessageBodyOther = 17
    RULE_baseCommand = 18
    RULE_exit = 19
    RULE_quit = 20
    RULE_use = 21
    RULE_sleep = 22
    RULE_start = 23
    RULE_load = 24
    RULE_assert = 25
    RULE_host = 26
    RULE_loop = 27
    RULE_if = 28
    RULE_endif = 29
    RULE_whenever = 30
    RULE_spool = 31
    RULE_echo = 32
    RULE_script = 33
    RULE_set = 34
    RULE_ssh = 35
    RULE_job = 36
    RULE_compare = 37
    RULE_data = 38
    RULE_help = 39
    RULE_monitor = 40

    ruleNames =  [ "prog", "command", "http", "httpMessage", "httpRequestLine", 
                   "httpMethod", "httpRequestTarget", "httpHeaderFields", 
                   "httpHeaderField", "httpHeaderFieldName", "httpHeaderFieldValue", 
                   "httpMessageBody", "httpMultipart", "httpMultipartBoundary", 
                   "httpBoundaryDelimiter", "httpMessageBodyContent", "httpMessageBodyOperate", 
                   "httpMessageBodyOther", "baseCommand", "exit", "quit", 
                   "use", "sleep", "start", "load", "assert", "host", "loop", 
                   "if", "endif", "whenever", "spool", "echo", "script", 
                   "set", "ssh", "job", "compare", "data", "help", "monitor" ]

    EOF = Token.EOF
    HTTP_OPEN=1
    COMMENT1=2
    COMMENT2=3
    CRLF=4
    COMMA=5
    SEMICOLON=6
    COLON=7
    AT=8
    DOT=9
    SLASH=10
    BRACKET_OPEN=11
    BRACKET_CLOSE=12
    SQUARE_OPEN=13
    SQUARE_CLOSE=14
    DOUBLE_QUOTE=15
    SINGLE_QUOTE=16
    ESCAPE=17
    SPACE=18
    EXIT=19
    QUIT=20
    SPOOL=21
    SLEEP=22
    USE=23
    ECHO=24
    SCRIPT=25
    ASSERT=26
    START=27
    LOAD=28
    HOST=29
    HELP=30
    IF=31
    ENDIF=32
    SET=33
    LOOP=34
    WHENEVER=35
    SSH=36
    JOB=37
    COMPARE=38
    DATA=39
    MONITOR=40
    INT=41
    DECIMAL=42
    String=43
    HTTP_COMMENT=44
    DIVIDE=45
    SP=46
    HttpMethod=47
    HTTP_CLOSE=48
    HttpRequestTarget=49
    HttpHeaderFieldName=50
    FIELD_COLON=51
    FIELD_CRLF=52
    HttpHeaderFieldValue=53
    HttpHeaderFieldValueEnd=54
    HttpMultipartBoundaryEnd=55
    HttpMultipartBoundary=56
    HttpMessageBodyComment=57
    HttpMessageBodyOperate=58
    ScriptBlock=59
    EchoBlock=60
    ASSERT_SPACE=61
    ASSERT_OPEN=62
    ASSERT_CLOSE=63
    ASSERT_CRLF=64
    ASSERT_EXPRESSION=65
    ASSERT_NAME=66
    ASSERT_COMMA=67
    ASSERT_SEMICOLON=68
    LOAD_SPACE=69
    LOAD_EQUAL=70
    LOAD_PLUGIN=71
    LOAD_MAP=72
    LOAD_JDBCDRIVER=73
    LOAD_JDBCFILE=74
    LOAD_JDBCCLASS=75
    LOAD_JDBCNAME=76
    LOAD_JDBCPROP=77
    LOAD_JDBCURL=78
    LOAD_EXPRESSION=79
    LOAD_SEMICOLON=80
    LOAD_CRLF=81
    START_SPACE=82
    START_EXPRESSION=83
    START_CRLF=84
    HOST_SPACE=85
    HOST_EXPRESSION=86
    HOST_CRLF=87
    IF_SPACE=88
    IF_OPEN=89
    IF_CLOSE=90
    IF_EXPRESSION=91
    LOOP_SEMICOLON=92
    LOOP_SPACE=93
    LOOP_BEGIN=94
    LOOP_UNTIL=95
    LOOP_OPEN=96
    LOOP_CLOSE=97
    LOOP_BREAK=98
    LOOP_END=99
    LOOP_CONTINUE=100
    LOOP_EXPRESSION=101
    LOOP_CRLF=102
    WHENEVER_SPACE=103
    WHENEVER_EXITCODE=104
    WHENEVER_ERROR=105
    WHENEVER_SEMICOLON=106
    WHENEVER_CONTINUE=107
    WHENEVER_EXIT=108
    WHENEVER_CRLF=109
    SET_SPACE=110
    SET_EXPRESSION=111
    SET_SEMICOLON=112
    SET_CRLF=113
    USE_API=114
    USE_SQL=115
    USE_SPACE=116
    USE_SEMICOLON=117
    USE_CRLF=118
    SSH_CONNECT=119
    SSH_WITH=120
    SSH_USER=121
    SSH_KEYFILE=122
    SSH_PASSWORD=123
    SSH_EXECUTE=124
    SSH_DISCONNECT=125
    SSH_SAVE=126
    SSH_RESTORE=127
    SSH_INT=128
    SFTP=129
    SFTP_CHMOD=130
    SFTP_GETCWD=131
    SFTP_CHDIR=132
    SFTP_CHOWN=133
    SFTP_MKDIR=134
    SFTP_GET=135
    SFTP_PUT=136
    SFTP_REMOVE=137
    SFTP_RENAME=138
    SFTP_LISTDIR=139
    SFTP_TRUNCATE=140
    SSH_SPACE=141
    SSH_SEMICOLON=142
    SSH_CRLF=143
    SSH_EXPRESSION=144
    JOB_SPACE=145
    JOB_SEMICOLON=146
    JOB_EQUAL=147
    JOB_CRLF=148
    JOB_CREATE=149
    JOB_SHOW=150
    JOB_SET=151
    JOB_START=152
    JOB_WAIT=153
    JOB_SHUTDOWN=154
    JOB_ABORT=155
    JOB_TIMER=156
    JOB_REGISTER=157
    JOB_DEREGISTER=158
    JOB_WORKER=159
    JOB_MANGER=160
    JOB_ON=161
    JOB_OFF=162
    JOB_TO=163
    JOB_EXPRESSION=164
    COMPARE_SPACE=165
    COMPARE_SEMICOLON=166
    COMPARE_EQUAL=167
    COMPARE_CRLF=168
    COMPARE_SET=169
    COMPARE_UNSET=170
    COMPARE_MASK=171
    COMPARE_NOMASK=172
    COMPARE_MASKLINE=173
    COMPARE_NOMASKLINE=174
    COMPARE_CASE=175
    COMPARE_NOCASE=176
    COMPARE_IGBLANK=177
    COMPARE_NOIGBLANK=178
    COMPARE_TRIM=179
    COMPARE_NOTRIM=180
    COMPARE_OUTPUT=181
    COMPARE_CONSOLE=182
    COMPARE_DIFFFILE=183
    COMPARE_SKIPLINE=184
    COMPARE_NOSKIPLINE=185
    COMPARE_RESET=186
    COMPARE_ALGORITHM=187
    COMPARE_ENCODING=188
    COMPARE_WORK=189
    COMPARE_REFERENCE=190
    COMPARE_LCS=191
    COMPARE_MYERS=192
    COMPARE_EXPRESSION=193
    DATA_SPACE=194
    DATA_SEMICOLON=195
    DATA_SET=196
    DATA_SEEDFILE=197
    DATA_DIR=198
    DATA_CREATE=199
    DATA_FILE=200
    DATA_FILETYPE=201
    DATA_ROWS=202
    DATA_INT=203
    DATA_COMMA=204
    DATACOLUMN_OPEN=205
    DATA_CONVERT=206
    DATA_TO=207
    DATA_EXPRESSION=208
    DATACOLUMN_SPACE=209
    DATACOLUMN_CLOSE=210
    DATACOLUMN_CONTENT=211
    HELP_SPACE=212
    HELP_COMMAND=213
    HELP_CRLF=214
    HELP_SEMICOLON=215
    MONITOR_SPACE=216
    MONITOR_MANAGER=217
    MONITOR_WORKERS=218
    MONITOR_CREATE=219
    MONITOR_TASK=220
    MONITOR_EQUAL=221
    MONITOR_START=222
    MONITOR_STOP=223
    MONITOR_REPORT=224
    MONITOR_LIST=225
    MONITOR_ON=226
    MONITOR_OFF=227
    MONITOR_EXPRESSION=228
    MONITOR_CRLF=229
    MONITOR_SEMICOLON=230

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.11.1")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class ProgContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def command(self):
            return self.getTypedRuleContext(APIParser.CommandContext,0)


        def EOF(self):
            return self.getToken(APIParser.EOF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_prog

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitProg" ):
                return visitor.visitProg(self)
            else:
                return visitor.visitChildren(self)




    def prog(self):

        localctx = APIParser.ProgContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_prog)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 82
            self.command()
            self.state = 83
            self.match(APIParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CommandContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def baseCommand(self):
            return self.getTypedRuleContext(APIParser.BaseCommandContext,0)


        def http(self):
            return self.getTypedRuleContext(APIParser.HttpContext,0)


        def EOF(self):
            return self.getToken(APIParser.EOF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_command

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCommand" ):
                return visitor.visitCommand(self)
            else:
                return visitor.visitChildren(self)




    def command(self):

        localctx = APIParser.CommandContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_command)
        try:
            self.state = 88
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40]:
                self.enterOuterAlt(localctx, 1)
                self.state = 85
                self.baseCommand()
                pass
            elif token in [1]:
                self.enterOuterAlt(localctx, 2)
                self.state = 86
                self.http()
                pass
            elif token in [-1]:
                self.enterOuterAlt(localctx, 3)
                self.state = 87
                self.match(APIParser.EOF)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HTTP_OPEN(self):
            return self.getToken(APIParser.HTTP_OPEN, 0)

        def httpMessage(self):
            return self.getTypedRuleContext(APIParser.HttpMessageContext,0)


        def HTTP_CLOSE(self):
            return self.getToken(APIParser.HTTP_CLOSE, 0)

        def EOF(self):
            return self.getToken(APIParser.EOF, 0)

        def CRLF(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.CRLF)
            else:
                return self.getToken(APIParser.CRLF, i)

        def getRuleIndex(self):
            return APIParser.RULE_http

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttp" ):
                return visitor.visitHttp(self)
            else:
                return visitor.visitChildren(self)




    def http(self):

        localctx = APIParser.HttpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_http)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 90
            self.match(APIParser.HTTP_OPEN)
            self.state = 94
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==4:
                self.state = 91
                self.match(APIParser.CRLF)
                self.state = 96
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 97
            self.httpMessage()
            self.state = 98
            _la = self._input.LA(1)
            if not(_la==-1 or _la==48):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMessageContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpRequestLine(self):
            return self.getTypedRuleContext(APIParser.HttpRequestLineContext,0)


        def httpHeaderFields(self):
            return self.getTypedRuleContext(APIParser.HttpHeaderFieldsContext,0)


        def httpMessageBody(self):
            return self.getTypedRuleContext(APIParser.HttpMessageBodyContext,0)


        def getRuleIndex(self):
            return APIParser.RULE_httpMessage

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMessage" ):
                return visitor.visitHttpMessage(self)
            else:
                return visitor.visitChildren(self)




    def httpMessage(self):

        localctx = APIParser.HttpMessageContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_httpMessage)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 100
            self.httpRequestLine()
            self.state = 101
            self.httpHeaderFields()
            self.state = 103
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if ((_la) & ~0x3f) == 0 and ((1 << _la) & 360296766282661904) != 0:
                self.state = 102
                self.httpMessageBody()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpRequestLineContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpMethod(self):
            return self.getTypedRuleContext(APIParser.HttpMethodContext,0)


        def httpRequestTarget(self):
            return self.getTypedRuleContext(APIParser.HttpRequestTargetContext,0)


        def getRuleIndex(self):
            return APIParser.RULE_httpRequestLine

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpRequestLine" ):
                return visitor.visitHttpRequestLine(self)
            else:
                return visitor.visitChildren(self)




    def httpRequestLine(self):

        localctx = APIParser.HttpRequestLineContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_httpRequestLine)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 105
            self.httpMethod()
            self.state = 106
            self.httpRequestTarget()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMethodContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpMethod(self):
            return self.getToken(APIParser.HttpMethod, 0)

        def getRuleIndex(self):
            return APIParser.RULE_httpMethod

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMethod" ):
                return visitor.visitHttpMethod(self)
            else:
                return visitor.visitChildren(self)




    def httpMethod(self):

        localctx = APIParser.HttpMethodContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_httpMethod)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 108
            self.match(APIParser.HttpMethod)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpRequestTargetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpRequestTarget(self):
            return self.getToken(APIParser.HttpRequestTarget, 0)

        def getRuleIndex(self):
            return APIParser.RULE_httpRequestTarget

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpRequestTarget" ):
                return visitor.visitHttpRequestTarget(self)
            else:
                return visitor.visitChildren(self)




    def httpRequestTarget(self):

        localctx = APIParser.HttpRequestTargetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_httpRequestTarget)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 110
            self.match(APIParser.HttpRequestTarget)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpHeaderFieldsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpHeaderField(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(APIParser.HttpHeaderFieldContext)
            else:
                return self.getTypedRuleContext(APIParser.HttpHeaderFieldContext,i)


        def getRuleIndex(self):
            return APIParser.RULE_httpHeaderFields

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpHeaderFields" ):
                return visitor.visitHttpHeaderFields(self)
            else:
                return visitor.visitChildren(self)




    def httpHeaderFields(self):

        localctx = APIParser.HttpHeaderFieldsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_httpHeaderFields)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 115
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==50:
                self.state = 112
                self.httpHeaderField()
                self.state = 117
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpHeaderFieldContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpHeaderFieldName(self):
            return self.getTypedRuleContext(APIParser.HttpHeaderFieldNameContext,0)


        def FIELD_COLON(self):
            return self.getToken(APIParser.FIELD_COLON, 0)

        def httpHeaderFieldValue(self):
            return self.getTypedRuleContext(APIParser.HttpHeaderFieldValueContext,0)


        def getRuleIndex(self):
            return APIParser.RULE_httpHeaderField

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpHeaderField" ):
                return visitor.visitHttpHeaderField(self)
            else:
                return visitor.visitChildren(self)




    def httpHeaderField(self):

        localctx = APIParser.HttpHeaderFieldContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_httpHeaderField)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 118
            self.httpHeaderFieldName()
            self.state = 119
            self.match(APIParser.FIELD_COLON)
            self.state = 120
            self.httpHeaderFieldValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpHeaderFieldNameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpHeaderFieldName(self):
            return self.getToken(APIParser.HttpHeaderFieldName, 0)

        def getRuleIndex(self):
            return APIParser.RULE_httpHeaderFieldName

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpHeaderFieldName" ):
                return visitor.visitHttpHeaderFieldName(self)
            else:
                return visitor.visitChildren(self)




    def httpHeaderFieldName(self):

        localctx = APIParser.HttpHeaderFieldNameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_httpHeaderFieldName)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 122
            self.match(APIParser.HttpHeaderFieldName)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpHeaderFieldValueContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpHeaderFieldValue(self):
            return self.getToken(APIParser.HttpHeaderFieldValue, 0)

        def HttpHeaderFieldValueEnd(self):
            return self.getToken(APIParser.HttpHeaderFieldValueEnd, 0)

        def getRuleIndex(self):
            return APIParser.RULE_httpHeaderFieldValue

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpHeaderFieldValue" ):
                return visitor.visitHttpHeaderFieldValue(self)
            else:
                return visitor.visitChildren(self)




    def httpHeaderFieldValue(self):

        localctx = APIParser.HttpHeaderFieldValueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_httpHeaderFieldValue)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 124
            self.match(APIParser.HttpHeaderFieldValue)
            self.state = 125
            self.match(APIParser.HttpHeaderFieldValueEnd)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMessageBodyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpMultipart(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(APIParser.HttpMultipartContext)
            else:
                return self.getTypedRuleContext(APIParser.HttpMultipartContext,i)


        def httpMessageBodyContent(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(APIParser.HttpMessageBodyContentContext)
            else:
                return self.getTypedRuleContext(APIParser.HttpMessageBodyContentContext,i)


        def getRuleIndex(self):
            return APIParser.RULE_httpMessageBody

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMessageBody" ):
                return visitor.visitHttpMessageBody(self)
            else:
                return visitor.visitChildren(self)




    def httpMessageBody(self):

        localctx = APIParser.HttpMessageBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_httpMessageBody)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 129 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 129
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [56]:
                    self.state = 127
                    self.httpMultipart()
                    pass
                elif token in [4, 43, 58]:
                    self.state = 128
                    self.httpMessageBodyContent()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 131 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (((_la) & ~0x3f) == 0 and ((1 << _la) & 360296766282661904) != 0):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMultipartContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpMultipartBoundaryEnd(self):
            return self.getToken(APIParser.HttpMultipartBoundaryEnd, 0)

        def httpMultipartBoundary(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(APIParser.HttpMultipartBoundaryContext)
            else:
                return self.getTypedRuleContext(APIParser.HttpMultipartBoundaryContext,i)


        def getRuleIndex(self):
            return APIParser.RULE_httpMultipart

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMultipart" ):
                return visitor.visitHttpMultipart(self)
            else:
                return visitor.visitChildren(self)




    def httpMultipart(self):

        localctx = APIParser.HttpMultipartContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_httpMultipart)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 134 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 133
                self.httpMultipartBoundary()
                self.state = 136 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==56):
                    break

            self.state = 138
            self.match(APIParser.HttpMultipartBoundaryEnd)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMultipartBoundaryContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpBoundaryDelimiter(self):
            return self.getTypedRuleContext(APIParser.HttpBoundaryDelimiterContext,0)


        def httpHeaderFields(self):
            return self.getTypedRuleContext(APIParser.HttpHeaderFieldsContext,0)


        def httpMessageBodyContent(self):
            return self.getTypedRuleContext(APIParser.HttpMessageBodyContentContext,0)


        def getRuleIndex(self):
            return APIParser.RULE_httpMultipartBoundary

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMultipartBoundary" ):
                return visitor.visitHttpMultipartBoundary(self)
            else:
                return visitor.visitChildren(self)




    def httpMultipartBoundary(self):

        localctx = APIParser.HttpMultipartBoundaryContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_httpMultipartBoundary)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 140
            self.httpBoundaryDelimiter()
            self.state = 141
            self.httpHeaderFields()
            self.state = 142
            self.httpMessageBodyContent()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpBoundaryDelimiterContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpMultipartBoundary(self):
            return self.getToken(APIParser.HttpMultipartBoundary, 0)

        def getRuleIndex(self):
            return APIParser.RULE_httpBoundaryDelimiter

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpBoundaryDelimiter" ):
                return visitor.visitHttpBoundaryDelimiter(self)
            else:
                return visitor.visitChildren(self)




    def httpBoundaryDelimiter(self):

        localctx = APIParser.HttpBoundaryDelimiterContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_httpBoundaryDelimiter)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 144
            self.match(APIParser.HttpMultipartBoundary)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMessageBodyContentContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def httpMessageBodyOperate(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(APIParser.HttpMessageBodyOperateContext)
            else:
                return self.getTypedRuleContext(APIParser.HttpMessageBodyOperateContext,i)


        def httpMessageBodyOther(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(APIParser.HttpMessageBodyOtherContext)
            else:
                return self.getTypedRuleContext(APIParser.HttpMessageBodyOtherContext,i)


        def getRuleIndex(self):
            return APIParser.RULE_httpMessageBodyContent

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMessageBodyContent" ):
                return visitor.visitHttpMessageBodyContent(self)
            else:
                return visitor.visitChildren(self)




    def httpMessageBodyContent(self):

        localctx = APIParser.HttpMessageBodyContentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_httpMessageBodyContent)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 148 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 148
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [58]:
                        self.state = 146
                        self.httpMessageBodyOperate()
                        pass
                    elif token in [4, 43]:
                        self.state = 147
                        self.httpMessageBodyOther()
                        pass
                    else:
                        raise NoViableAltException(self)


                else:
                    raise NoViableAltException(self)
                self.state = 150 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,8,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMessageBodyOperateContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HttpMessageBodyOperate(self):
            return self.getToken(APIParser.HttpMessageBodyOperate, 0)

        def getRuleIndex(self):
            return APIParser.RULE_httpMessageBodyOperate

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMessageBodyOperate" ):
                return visitor.visitHttpMessageBodyOperate(self)
            else:
                return visitor.visitChildren(self)




    def httpMessageBodyOperate(self):

        localctx = APIParser.HttpMessageBodyOperateContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_httpMessageBodyOperate)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 152
            self.match(APIParser.HttpMessageBodyOperate)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HttpMessageBodyOtherContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.String)
            else:
                return self.getToken(APIParser.String, i)

        def CRLF(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.CRLF)
            else:
                return self.getToken(APIParser.CRLF, i)

        def getRuleIndex(self):
            return APIParser.RULE_httpMessageBodyOther

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHttpMessageBodyOther" ):
                return visitor.visitHttpMessageBodyOther(self)
            else:
                return visitor.visitChildren(self)




    def httpMessageBodyOther(self):

        localctx = APIParser.HttpMessageBodyOtherContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_httpMessageBodyOther)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 155 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 154
                    _la = self._input.LA(1)
                    if not(_la==4 or _la==43):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()

                else:
                    raise NoViableAltException(self)
                self.state = 157 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,9,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BaseCommandContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def assert_(self):
            return self.getTypedRuleContext(APIParser.AssertContext,0)


        def load(self):
            return self.getTypedRuleContext(APIParser.LoadContext,0)


        def host(self):
            return self.getTypedRuleContext(APIParser.HostContext,0)


        def start(self):
            return self.getTypedRuleContext(APIParser.StartContext,0)


        def loop(self):
            return self.getTypedRuleContext(APIParser.LoopContext,0)


        def if_(self):
            return self.getTypedRuleContext(APIParser.IfContext,0)


        def endif(self):
            return self.getTypedRuleContext(APIParser.EndifContext,0)


        def whenever(self):
            return self.getTypedRuleContext(APIParser.WheneverContext,0)


        def set_(self):
            return self.getTypedRuleContext(APIParser.SetContext,0)


        def use(self):
            return self.getTypedRuleContext(APIParser.UseContext,0)


        def exit(self):
            return self.getTypedRuleContext(APIParser.ExitContext,0)


        def quit(self):
            return self.getTypedRuleContext(APIParser.QuitContext,0)


        def sleep(self):
            return self.getTypedRuleContext(APIParser.SleepContext,0)


        def spool(self):
            return self.getTypedRuleContext(APIParser.SpoolContext,0)


        def script(self):
            return self.getTypedRuleContext(APIParser.ScriptContext,0)


        def echo(self):
            return self.getTypedRuleContext(APIParser.EchoContext,0)


        def ssh(self):
            return self.getTypedRuleContext(APIParser.SshContext,0)


        def job(self):
            return self.getTypedRuleContext(APIParser.JobContext,0)


        def compare(self):
            return self.getTypedRuleContext(APIParser.CompareContext,0)


        def data(self):
            return self.getTypedRuleContext(APIParser.DataContext,0)


        def help_(self):
            return self.getTypedRuleContext(APIParser.HelpContext,0)


        def monitor(self):
            return self.getTypedRuleContext(APIParser.MonitorContext,0)


        def getRuleIndex(self):
            return APIParser.RULE_baseCommand

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBaseCommand" ):
                return visitor.visitBaseCommand(self)
            else:
                return visitor.visitChildren(self)




    def baseCommand(self):

        localctx = APIParser.BaseCommandContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_baseCommand)
        try:
            self.state = 181
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [26]:
                self.enterOuterAlt(localctx, 1)
                self.state = 159
                self.assert_()
                pass
            elif token in [28]:
                self.enterOuterAlt(localctx, 2)
                self.state = 160
                self.load()
                pass
            elif token in [29]:
                self.enterOuterAlt(localctx, 3)
                self.state = 161
                self.host()
                pass
            elif token in [27]:
                self.enterOuterAlt(localctx, 4)
                self.state = 162
                self.start()
                pass
            elif token in [34]:
                self.enterOuterAlt(localctx, 5)
                self.state = 163
                self.loop()
                pass
            elif token in [31]:
                self.enterOuterAlt(localctx, 6)
                self.state = 164
                self.if_()
                pass
            elif token in [32]:
                self.enterOuterAlt(localctx, 7)
                self.state = 165
                self.endif()
                pass
            elif token in [35]:
                self.enterOuterAlt(localctx, 8)
                self.state = 166
                self.whenever()
                pass
            elif token in [33]:
                self.enterOuterAlt(localctx, 9)
                self.state = 167
                self.set_()
                pass
            elif token in [23]:
                self.enterOuterAlt(localctx, 10)
                self.state = 168
                self.use()
                pass
            elif token in [19]:
                self.enterOuterAlt(localctx, 11)
                self.state = 169
                self.exit()
                pass
            elif token in [20]:
                self.enterOuterAlt(localctx, 12)
                self.state = 170
                self.quit()
                pass
            elif token in [22]:
                self.enterOuterAlt(localctx, 13)
                self.state = 171
                self.sleep()
                pass
            elif token in [21]:
                self.enterOuterAlt(localctx, 14)
                self.state = 172
                self.spool()
                pass
            elif token in [25]:
                self.enterOuterAlt(localctx, 15)
                self.state = 173
                self.script()
                pass
            elif token in [24]:
                self.enterOuterAlt(localctx, 16)
                self.state = 174
                self.echo()
                pass
            elif token in [36]:
                self.enterOuterAlt(localctx, 17)
                self.state = 175
                self.ssh()
                pass
            elif token in [37]:
                self.enterOuterAlt(localctx, 18)
                self.state = 176
                self.job()
                pass
            elif token in [38]:
                self.enterOuterAlt(localctx, 19)
                self.state = 177
                self.compare()
                pass
            elif token in [39]:
                self.enterOuterAlt(localctx, 20)
                self.state = 178
                self.data()
                pass
            elif token in [30]:
                self.enterOuterAlt(localctx, 21)
                self.state = 179
                self.help_()
                pass
            elif token in [40]:
                self.enterOuterAlt(localctx, 22)
                self.state = 180
                self.monitor()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExitContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EXIT(self):
            return self.getToken(APIParser.EXIT, 0)

        def INT(self):
            return self.getToken(APIParser.INT, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_exit

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExit" ):
                return visitor.visitExit(self)
            else:
                return visitor.visitChildren(self)




    def exit(self):

        localctx = APIParser.ExitContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_exit)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 183
            self.match(APIParser.EXIT)
            self.state = 185
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==41:
                self.state = 184
                self.match(APIParser.INT)


            self.state = 188
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 187
                self.match(APIParser.SEMICOLON)


            self.state = 191
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 190
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class QuitContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def QUIT(self):
            return self.getToken(APIParser.QUIT, 0)

        def INT(self):
            return self.getToken(APIParser.INT, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_quit

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitQuit" ):
                return visitor.visitQuit(self)
            else:
                return visitor.visitChildren(self)




    def quit(self):

        localctx = APIParser.QuitContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_quit)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 193
            self.match(APIParser.QUIT)
            self.state = 195
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==41:
                self.state = 194
                self.match(APIParser.INT)


            self.state = 198
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 197
                self.match(APIParser.SEMICOLON)


            self.state = 201
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 200
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class UseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def USE(self):
            return self.getToken(APIParser.USE, 0)

        def USE_API(self):
            return self.getToken(APIParser.USE_API, 0)

        def USE_SQL(self):
            return self.getToken(APIParser.USE_SQL, 0)

        def USE_SEMICOLON(self):
            return self.getToken(APIParser.USE_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_use

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUse" ):
                return visitor.visitUse(self)
            else:
                return visitor.visitChildren(self)




    def use(self):

        localctx = APIParser.UseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_use)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 203
            self.match(APIParser.USE)
            self.state = 204
            _la = self._input.LA(1)
            if not(_la==114 or _la==115):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 206
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==117:
                self.state = 205
                self.match(APIParser.USE_SEMICOLON)


            self.state = 209
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 208
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SleepContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SLEEP(self):
            return self.getToken(APIParser.SLEEP, 0)

        def INT(self):
            return self.getToken(APIParser.INT, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_sleep

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSleep" ):
                return visitor.visitSleep(self)
            else:
                return visitor.visitChildren(self)




    def sleep(self):

        localctx = APIParser.SleepContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_sleep)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 211
            self.match(APIParser.SLEEP)
            self.state = 212
            self.match(APIParser.INT)
            self.state = 214
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 213
                self.match(APIParser.SEMICOLON)


            self.state = 217
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 216
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StartContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def START(self):
            return self.getToken(APIParser.START, 0)

        def START_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.START_EXPRESSION)
            else:
                return self.getToken(APIParser.START_EXPRESSION, i)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_start

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStart" ):
                return visitor.visitStart(self)
            else:
                return visitor.visitChildren(self)




    def start(self):

        localctx = APIParser.StartContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_start)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 219
            self.match(APIParser.START)
            self.state = 221 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 220
                self.match(APIParser.START_EXPRESSION)
                self.state = 223 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==83):
                    break

            self.state = 226
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 225
                self.match(APIParser.SEMICOLON)


            self.state = 229
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 228
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LoadContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LOAD(self):
            return self.getToken(APIParser.LOAD, 0)

        def LOAD_SEMICOLON(self):
            return self.getToken(APIParser.LOAD_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def LOAD_PLUGIN(self):
            return self.getToken(APIParser.LOAD_PLUGIN, 0)

        def LOAD_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_EXPRESSION)
            else:
                return self.getToken(APIParser.LOAD_EXPRESSION, i)

        def LOAD_MAP(self):
            return self.getToken(APIParser.LOAD_MAP, 0)

        def LOAD_JDBCDRIVER(self):
            return self.getToken(APIParser.LOAD_JDBCDRIVER, 0)

        def LOAD_JDBCCLASS(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_JDBCCLASS)
            else:
                return self.getToken(APIParser.LOAD_JDBCCLASS, i)

        def LOAD_EQUAL(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_EQUAL)
            else:
                return self.getToken(APIParser.LOAD_EQUAL, i)

        def LOAD_JDBCFILE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_JDBCFILE)
            else:
                return self.getToken(APIParser.LOAD_JDBCFILE, i)

        def LOAD_JDBCNAME(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_JDBCNAME)
            else:
                return self.getToken(APIParser.LOAD_JDBCNAME, i)

        def LOAD_JDBCPROP(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_JDBCPROP)
            else:
                return self.getToken(APIParser.LOAD_JDBCPROP, i)

        def LOAD_JDBCURL(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.LOAD_JDBCURL)
            else:
                return self.getToken(APIParser.LOAD_JDBCURL, i)

        def getRuleIndex(self):
            return APIParser.RULE_load

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLoad" ):
                return visitor.visitLoad(self)
            else:
                return visitor.visitChildren(self)




    def load(self):

        localctx = APIParser.LoadContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_load)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 231
            self.match(APIParser.LOAD)
            self.state = 257
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [71]:
                self.state = 232
                self.match(APIParser.LOAD_PLUGIN)
                self.state = 233
                self.match(APIParser.LOAD_EXPRESSION)
                pass
            elif token in [72]:
                self.state = 234
                self.match(APIParser.LOAD_MAP)
                self.state = 235
                self.match(APIParser.LOAD_EXPRESSION)
                pass
            elif token in [73]:
                self.state = 236
                self.match(APIParser.LOAD_JDBCDRIVER)
                self.state = 254
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la - 74)) & ~0x3f) == 0 and ((1 << (_la - 74)) & 31) != 0:
                    self.state = 252
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [75]:
                        self.state = 237
                        self.match(APIParser.LOAD_JDBCCLASS)
                        self.state = 238
                        self.match(APIParser.LOAD_EQUAL)
                        self.state = 239
                        self.match(APIParser.LOAD_EXPRESSION)
                        pass
                    elif token in [74]:
                        self.state = 240
                        self.match(APIParser.LOAD_JDBCFILE)
                        self.state = 241
                        self.match(APIParser.LOAD_EQUAL)
                        self.state = 242
                        self.match(APIParser.LOAD_EXPRESSION)
                        pass
                    elif token in [76]:
                        self.state = 243
                        self.match(APIParser.LOAD_JDBCNAME)
                        self.state = 244
                        self.match(APIParser.LOAD_EQUAL)
                        self.state = 245
                        self.match(APIParser.LOAD_EXPRESSION)
                        pass
                    elif token in [77]:
                        self.state = 246
                        self.match(APIParser.LOAD_JDBCPROP)
                        self.state = 247
                        self.match(APIParser.LOAD_EQUAL)
                        self.state = 248
                        self.match(APIParser.LOAD_EXPRESSION)
                        pass
                    elif token in [78]:
                        self.state = 249
                        self.match(APIParser.LOAD_JDBCURL)
                        self.state = 250
                        self.match(APIParser.LOAD_EQUAL)
                        self.state = 251
                        self.match(APIParser.LOAD_EXPRESSION)
                        pass
                    else:
                        raise NoViableAltException(self)

                    self.state = 256
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass
            else:
                raise NoViableAltException(self)

            self.state = 260
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==80:
                self.state = 259
                self.match(APIParser.LOAD_SEMICOLON)


            self.state = 263
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 262
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AssertContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ASSERT(self):
            return self.getToken(APIParser.ASSERT, 0)

        def ASSERT_EXPRESSION(self):
            return self.getToken(APIParser.ASSERT_EXPRESSION, 0)

        def ASSERT_NAME(self):
            return self.getToken(APIParser.ASSERT_NAME, 0)

        def ASSERT_SEMICOLON(self):
            return self.getToken(APIParser.ASSERT_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def ASSERT_COMMA(self):
            return self.getToken(APIParser.ASSERT_COMMA, 0)

        def getRuleIndex(self):
            return APIParser.RULE_assert

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAssert" ):
                return visitor.visitAssert(self)
            else:
                return visitor.visitChildren(self)




    def assert_(self):

        localctx = APIParser.AssertContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_assert)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 265
            self.match(APIParser.ASSERT)
            self.state = 266
            self.match(APIParser.ASSERT_EXPRESSION)
            self.state = 271
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==66 or _la==67:
                self.state = 268
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==67:
                    self.state = 267
                    self.match(APIParser.ASSERT_COMMA)


                self.state = 270
                self.match(APIParser.ASSERT_NAME)


            self.state = 274
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==68:
                self.state = 273
                self.match(APIParser.ASSERT_SEMICOLON)


            self.state = 277
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 276
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HostContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HOST(self):
            return self.getToken(APIParser.HOST, 0)

        def HOST_EXPRESSION(self):
            return self.getToken(APIParser.HOST_EXPRESSION, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_host

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHost" ):
                return visitor.visitHost(self)
            else:
                return visitor.visitChildren(self)




    def host(self):

        localctx = APIParser.HostContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_host)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 279
            self.match(APIParser.HOST)
            self.state = 280
            self.match(APIParser.HOST_EXPRESSION)
            self.state = 282
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 281
                self.match(APIParser.SEMICOLON)


            self.state = 285
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 284
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LoopContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LOOP(self):
            return self.getToken(APIParser.LOOP, 0)

        def LOOP_BREAK(self):
            return self.getToken(APIParser.LOOP_BREAK, 0)

        def LOOP_END(self):
            return self.getToken(APIParser.LOOP_END, 0)

        def LOOP_CONTINUE(self):
            return self.getToken(APIParser.LOOP_CONTINUE, 0)

        def LOOP_BEGIN(self):
            return self.getToken(APIParser.LOOP_BEGIN, 0)

        def LOOP_UNTIL(self):
            return self.getToken(APIParser.LOOP_UNTIL, 0)

        def LOOP_EXPRESSION(self):
            return self.getToken(APIParser.LOOP_EXPRESSION, 0)

        def LOOP_SEMICOLON(self):
            return self.getToken(APIParser.LOOP_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_loop

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLoop" ):
                return visitor.visitLoop(self)
            else:
                return visitor.visitChildren(self)




    def loop(self):

        localctx = APIParser.LoopContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_loop)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 287
            self.match(APIParser.LOOP)
            self.state = 294
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [98]:
                self.state = 288
                self.match(APIParser.LOOP_BREAK)
                pass
            elif token in [99]:
                self.state = 289
                self.match(APIParser.LOOP_END)
                pass
            elif token in [100]:
                self.state = 290
                self.match(APIParser.LOOP_CONTINUE)
                pass
            elif token in [94]:
                self.state = 291
                self.match(APIParser.LOOP_BEGIN)
                self.state = 292
                self.match(APIParser.LOOP_UNTIL)
                self.state = 293
                self.match(APIParser.LOOP_EXPRESSION)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 297
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==92:
                self.state = 296
                self.match(APIParser.LOOP_SEMICOLON)


            self.state = 300
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 299
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class IfContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def IF(self):
            return self.getToken(APIParser.IF, 0)

        def IF_EXPRESSION(self):
            return self.getToken(APIParser.IF_EXPRESSION, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_if

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitIf" ):
                return visitor.visitIf(self)
            else:
                return visitor.visitChildren(self)




    def if_(self):

        localctx = APIParser.IfContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_if)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 302
            self.match(APIParser.IF)
            self.state = 303
            self.match(APIParser.IF_EXPRESSION)
            self.state = 305
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 304
                self.match(APIParser.SEMICOLON)


            self.state = 308
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 307
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EndifContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ENDIF(self):
            return self.getToken(APIParser.ENDIF, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_endif

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEndif" ):
                return visitor.visitEndif(self)
            else:
                return visitor.visitChildren(self)




    def endif(self):

        localctx = APIParser.EndifContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_endif)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 310
            self.match(APIParser.ENDIF)
            self.state = 312
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 311
                self.match(APIParser.SEMICOLON)


            self.state = 315
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 314
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class WheneverContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def WHENEVER(self):
            return self.getToken(APIParser.WHENEVER, 0)

        def WHENEVER_ERROR(self):
            return self.getToken(APIParser.WHENEVER_ERROR, 0)

        def WHENEVER_CONTINUE(self):
            return self.getToken(APIParser.WHENEVER_CONTINUE, 0)

        def WHENEVER_SEMICOLON(self):
            return self.getToken(APIParser.WHENEVER_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def WHENEVER_EXIT(self):
            return self.getToken(APIParser.WHENEVER_EXIT, 0)

        def WHENEVER_EXITCODE(self):
            return self.getToken(APIParser.WHENEVER_EXITCODE, 0)

        def getRuleIndex(self):
            return APIParser.RULE_whenever

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWhenever" ):
                return visitor.visitWhenever(self)
            else:
                return visitor.visitChildren(self)




    def whenever(self):

        localctx = APIParser.WheneverContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_whenever)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 317
            self.match(APIParser.WHENEVER)
            self.state = 318
            self.match(APIParser.WHENEVER_ERROR)
            self.state = 322
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [107]:
                self.state = 319
                self.match(APIParser.WHENEVER_CONTINUE)
                pass
            elif token in [108]:
                self.state = 320
                self.match(APIParser.WHENEVER_EXIT)
                self.state = 321
                self.match(APIParser.WHENEVER_EXITCODE)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 325
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==106:
                self.state = 324
                self.match(APIParser.WHENEVER_SEMICOLON)


            self.state = 328
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 327
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SpoolContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SPOOL(self):
            return self.getToken(APIParser.SPOOL, 0)

        def String(self):
            return self.getToken(APIParser.String, 0)

        def SEMICOLON(self):
            return self.getToken(APIParser.SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_spool

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSpool" ):
                return visitor.visitSpool(self)
            else:
                return visitor.visitChildren(self)




    def spool(self):

        localctx = APIParser.SpoolContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_spool)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 330
            self.match(APIParser.SPOOL)
            self.state = 331
            self.match(APIParser.String)
            self.state = 333
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 332
                self.match(APIParser.SEMICOLON)


            self.state = 336
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 335
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class EchoContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ECHO(self):
            return self.getToken(APIParser.ECHO, 0)

        def EchoBlock(self):
            return self.getToken(APIParser.EchoBlock, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def EOF(self):
            return self.getToken(APIParser.EOF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_echo

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitEcho" ):
                return visitor.visitEcho(self)
            else:
                return visitor.visitChildren(self)




    def echo(self):

        localctx = APIParser.EchoContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_echo)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 338
            self.match(APIParser.ECHO)
            self.state = 339
            self.match(APIParser.EchoBlock)
            self.state = 341
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,47,self._ctx)
            if la_ == 1:
                self.state = 340
                _la = self._input.LA(1)
                if not(_la==-1 or _la==4):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ScriptContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SCRIPT(self):
            return self.getToken(APIParser.SCRIPT, 0)

        def ScriptBlock(self):
            return self.getToken(APIParser.ScriptBlock, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_script

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitScript" ):
                return visitor.visitScript(self)
            else:
                return visitor.visitChildren(self)




    def script(self):

        localctx = APIParser.ScriptContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_script)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 343
            self.match(APIParser.SCRIPT)
            self.state = 344
            self.match(APIParser.ScriptBlock)
            self.state = 346
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 345
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SET(self):
            return self.getToken(APIParser.SET, 0)

        def SET_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.SET_EXPRESSION)
            else:
                return self.getToken(APIParser.SET_EXPRESSION, i)

        def SET_SEMICOLON(self):
            return self.getToken(APIParser.SET_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_set

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSet" ):
                return visitor.visitSet(self)
            else:
                return visitor.visitChildren(self)




    def set_(self):

        localctx = APIParser.SetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_set)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 348
            self.match(APIParser.SET)
            self.state = 352
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==111:
                self.state = 349
                self.match(APIParser.SET_EXPRESSION)
                self.state = 354
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 356
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==112:
                self.state = 355
                self.match(APIParser.SET_SEMICOLON)


            self.state = 359
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 358
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SshContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SSH(self):
            return self.getToken(APIParser.SSH, 0)

        def SSH_SEMICOLON(self):
            return self.getToken(APIParser.SSH_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def SSH_CONNECT(self):
            return self.getToken(APIParser.SSH_CONNECT, 0)

        def SSH_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.SSH_EXPRESSION)
            else:
                return self.getToken(APIParser.SSH_EXPRESSION, i)

        def SSH_WITH(self):
            return self.getToken(APIParser.SSH_WITH, 0)

        def SSH_USER(self):
            return self.getToken(APIParser.SSH_USER, 0)

        def SSH_KEYFILE(self):
            return self.getToken(APIParser.SSH_KEYFILE, 0)

        def SSH_EXECUTE(self):
            return self.getToken(APIParser.SSH_EXECUTE, 0)

        def SSH_DISCONNECT(self):
            return self.getToken(APIParser.SSH_DISCONNECT, 0)

        def SSH_SAVE(self):
            return self.getToken(APIParser.SSH_SAVE, 0)

        def SSH_RESTORE(self):
            return self.getToken(APIParser.SSH_RESTORE, 0)

        def SFTP(self):
            return self.getToken(APIParser.SFTP, 0)

        def SSH_PASSWORD(self):
            return self.getToken(APIParser.SSH_PASSWORD, 0)

        def SFTP_CHMOD(self):
            return self.getToken(APIParser.SFTP_CHMOD, 0)

        def SSH_INT(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.SSH_INT)
            else:
                return self.getToken(APIParser.SSH_INT, i)

        def SFTP_GETCWD(self):
            return self.getToken(APIParser.SFTP_GETCWD, 0)

        def SFTP_CHDIR(self):
            return self.getToken(APIParser.SFTP_CHDIR, 0)

        def SFTP_CHOWN(self):
            return self.getToken(APIParser.SFTP_CHOWN, 0)

        def SFTP_MKDIR(self):
            return self.getToken(APIParser.SFTP_MKDIR, 0)

        def SFTP_GET(self):
            return self.getToken(APIParser.SFTP_GET, 0)

        def SFTP_PUT(self):
            return self.getToken(APIParser.SFTP_PUT, 0)

        def SFTP_REMOVE(self):
            return self.getToken(APIParser.SFTP_REMOVE, 0)

        def SFTP_RENAME(self):
            return self.getToken(APIParser.SFTP_RENAME, 0)

        def SFTP_LISTDIR(self):
            return self.getToken(APIParser.SFTP_LISTDIR, 0)

        def SFTP_TRUNCATE(self):
            return self.getToken(APIParser.SFTP_TRUNCATE, 0)

        def getRuleIndex(self):
            return APIParser.RULE_ssh

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSsh" ):
                return visitor.visitSsh(self)
            else:
                return visitor.visitChildren(self)




    def ssh(self):

        localctx = APIParser.SshContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_ssh)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 361
            self.match(APIParser.SSH)
            self.state = 421
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,55,self._ctx)
            if la_ == 1:
                self.state = 362
                self.match(APIParser.SSH_CONNECT)
                self.state = 363
                self.match(APIParser.SSH_EXPRESSION)
                self.state = 364
                self.match(APIParser.SSH_WITH)
                self.state = 365
                self.match(APIParser.SSH_USER)
                self.state = 366
                self.match(APIParser.SSH_EXPRESSION)
                self.state = 367
                self.match(APIParser.SSH_KEYFILE)
                self.state = 368
                self.match(APIParser.SSH_EXPRESSION)
                pass

            elif la_ == 2:
                self.state = 369
                self.match(APIParser.SSH_CONNECT)
                self.state = 370
                self.match(APIParser.SSH_EXPRESSION)
                self.state = 371
                self.match(APIParser.SSH_WITH)
                self.state = 372
                self.match(APIParser.SSH_USER)
                self.state = 373
                self.match(APIParser.SSH_EXPRESSION)
                self.state = 376
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==123:
                    self.state = 374
                    self.match(APIParser.SSH_PASSWORD)
                    self.state = 375
                    self.match(APIParser.SSH_EXPRESSION)


                pass

            elif la_ == 3:
                self.state = 378
                self.match(APIParser.SSH_EXECUTE)
                self.state = 380 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 379
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 382 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==144):
                        break

                pass

            elif la_ == 4:
                self.state = 384
                self.match(APIParser.SSH_DISCONNECT)
                pass

            elif la_ == 5:
                self.state = 385
                self.match(APIParser.SSH_SAVE)
                self.state = 386
                self.match(APIParser.SSH_EXPRESSION)
                pass

            elif la_ == 6:
                self.state = 387
                self.match(APIParser.SSH_RESTORE)
                self.state = 388
                self.match(APIParser.SSH_EXPRESSION)
                pass

            elif la_ == 7:
                self.state = 389
                self.match(APIParser.SFTP)
                self.state = 419
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [130]:
                    self.state = 390
                    self.match(APIParser.SFTP_CHMOD)
                    self.state = 391
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 392
                    self.match(APIParser.SSH_INT)
                    pass
                elif token in [131]:
                    self.state = 393
                    self.match(APIParser.SFTP_GETCWD)
                    pass
                elif token in [132]:
                    self.state = 394
                    self.match(APIParser.SFTP_CHDIR)
                    self.state = 395
                    self.match(APIParser.SSH_EXPRESSION)
                    pass
                elif token in [133]:
                    self.state = 396
                    self.match(APIParser.SFTP_CHOWN)
                    self.state = 397
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 398
                    self.match(APIParser.SSH_INT)
                    self.state = 399
                    self.match(APIParser.SSH_INT)
                    pass
                elif token in [134]:
                    self.state = 400
                    self.match(APIParser.SFTP_MKDIR)
                    self.state = 401
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 402
                    self.match(APIParser.SSH_INT)
                    pass
                elif token in [135]:
                    self.state = 403
                    self.match(APIParser.SFTP_GET)
                    self.state = 404
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 405
                    self.match(APIParser.SSH_EXPRESSION)
                    pass
                elif token in [136]:
                    self.state = 406
                    self.match(APIParser.SFTP_PUT)
                    self.state = 407
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 408
                    self.match(APIParser.SSH_EXPRESSION)
                    pass
                elif token in [137]:
                    self.state = 409
                    self.match(APIParser.SFTP_REMOVE)
                    self.state = 410
                    self.match(APIParser.SSH_EXPRESSION)
                    pass
                elif token in [138]:
                    self.state = 411
                    self.match(APIParser.SFTP_RENAME)
                    self.state = 412
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 413
                    self.match(APIParser.SSH_EXPRESSION)
                    pass
                elif token in [139]:
                    self.state = 414
                    self.match(APIParser.SFTP_LISTDIR)
                    self.state = 415
                    self.match(APIParser.SSH_EXPRESSION)
                    pass
                elif token in [140]:
                    self.state = 416
                    self.match(APIParser.SFTP_TRUNCATE)
                    self.state = 417
                    self.match(APIParser.SSH_EXPRESSION)
                    self.state = 418
                    self.match(APIParser.SSH_INT)
                    pass
                else:
                    raise NoViableAltException(self)

                pass


            self.state = 424
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==142:
                self.state = 423
                self.match(APIParser.SSH_SEMICOLON)


            self.state = 427
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 426
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class JobContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def JOB(self):
            return self.getToken(APIParser.JOB, 0)

        def JOB_SEMICOLON(self):
            return self.getToken(APIParser.JOB_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def JOB_MANGER(self):
            return self.getToken(APIParser.JOB_MANGER, 0)

        def JOB_WAIT(self):
            return self.getToken(APIParser.JOB_WAIT, 0)

        def JOB_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.JOB_EXPRESSION)
            else:
                return self.getToken(APIParser.JOB_EXPRESSION, i)

        def JOB_SHOW(self):
            return self.getToken(APIParser.JOB_SHOW, 0)

        def JOB_ABORT(self):
            return self.getToken(APIParser.JOB_ABORT, 0)

        def JOB_SHUTDOWN(self):
            return self.getToken(APIParser.JOB_SHUTDOWN, 0)

        def JOB_TIMER(self):
            return self.getToken(APIParser.JOB_TIMER, 0)

        def JOB_START(self):
            return self.getToken(APIParser.JOB_START, 0)

        def JOB_DEREGISTER(self):
            return self.getToken(APIParser.JOB_DEREGISTER, 0)

        def JOB_WORKER(self):
            return self.getToken(APIParser.JOB_WORKER, 0)

        def JOB_REGISTER(self):
            return self.getToken(APIParser.JOB_REGISTER, 0)

        def JOB_TO(self):
            return self.getToken(APIParser.JOB_TO, 0)

        def JOB_SET(self):
            return self.getToken(APIParser.JOB_SET, 0)

        def JOB_CREATE(self):
            return self.getToken(APIParser.JOB_CREATE, 0)

        def JOB_ON(self):
            return self.getToken(APIParser.JOB_ON, 0)

        def JOB_OFF(self):
            return self.getToken(APIParser.JOB_OFF, 0)

        def JOB_EQUAL(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.JOB_EQUAL)
            else:
                return self.getToken(APIParser.JOB_EQUAL, i)

        def getRuleIndex(self):
            return APIParser.RULE_job

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitJob" ):
                return visitor.visitJob(self)
            else:
                return visitor.visitChildren(self)




    def job(self):

        localctx = APIParser.JobContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_job)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 429
            self.match(APIParser.JOB)
            self.state = 469
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [160]:
                self.state = 430
                self.match(APIParser.JOB_MANGER)
                self.state = 431
                _la = self._input.LA(1)
                if not(_la==161 or _la==162):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [153]:
                self.state = 432
                self.match(APIParser.JOB_WAIT)
                self.state = 433
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [150]:
                self.state = 434
                self.match(APIParser.JOB_SHOW)
                self.state = 435
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [155]:
                self.state = 436
                self.match(APIParser.JOB_ABORT)
                self.state = 437
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [154]:
                self.state = 438
                self.match(APIParser.JOB_SHUTDOWN)
                self.state = 439
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [156]:
                self.state = 440
                self.match(APIParser.JOB_TIMER)
                self.state = 441
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [152]:
                self.state = 442
                self.match(APIParser.JOB_START)
                self.state = 443
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [158]:
                self.state = 444
                self.match(APIParser.JOB_DEREGISTER)
                self.state = 445
                self.match(APIParser.JOB_WORKER)
                pass
            elif token in [157]:
                self.state = 446
                self.match(APIParser.JOB_REGISTER)
                self.state = 447
                self.match(APIParser.JOB_WORKER)
                self.state = 448
                self.match(APIParser.JOB_TO)
                self.state = 449
                self.match(APIParser.JOB_EXPRESSION)
                pass
            elif token in [151]:
                self.state = 450
                self.match(APIParser.JOB_SET)
                self.state = 451
                self.match(APIParser.JOB_EXPRESSION)
                self.state = 455 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 452
                    self.match(APIParser.JOB_EXPRESSION)
                    self.state = 453
                    self.match(APIParser.JOB_EQUAL)
                    self.state = 454
                    self.match(APIParser.JOB_EXPRESSION)
                    self.state = 457 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==164):
                        break

                pass
            elif token in [149]:
                self.state = 459
                self.match(APIParser.JOB_CREATE)
                self.state = 460
                self.match(APIParser.JOB_EXPRESSION)
                self.state = 466
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==164:
                    self.state = 461
                    self.match(APIParser.JOB_EXPRESSION)
                    self.state = 462
                    self.match(APIParser.JOB_EQUAL)
                    self.state = 463
                    self.match(APIParser.JOB_EXPRESSION)
                    self.state = 468
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass
            else:
                raise NoViableAltException(self)

            self.state = 472
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==146:
                self.state = 471
                self.match(APIParser.JOB_SEMICOLON)


            self.state = 475
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 474
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CompareContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COMPARE(self):
            return self.getToken(APIParser.COMPARE, 0)

        def COMPARE_RESET(self):
            return self.getToken(APIParser.COMPARE_RESET, 0)

        def COMPARE_SEMICOLON(self):
            return self.getToken(APIParser.COMPARE_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def COMPARE_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_EXPRESSION)
            else:
                return self.getToken(APIParser.COMPARE_EXPRESSION, i)

        def COMPARE_MASKLINE(self):
            return self.getToken(APIParser.COMPARE_MASKLINE, 0)

        def COMPARE_EQUAL(self):
            return self.getToken(APIParser.COMPARE_EQUAL, 0)

        def COMPARE_NOMASKLINE(self):
            return self.getToken(APIParser.COMPARE_NOMASKLINE, 0)

        def COMPARE_SET(self):
            return self.getToken(APIParser.COMPARE_SET, 0)

        def COMPARE_OUTPUT(self):
            return self.getToken(APIParser.COMPARE_OUTPUT, 0)

        def COMPARE_ALGORITHM(self):
            return self.getToken(APIParser.COMPARE_ALGORITHM, 0)

        def COMPARE_ENCODING(self):
            return self.getToken(APIParser.COMPARE_ENCODING, 0)

        def COMPARE_SKIPLINE(self):
            return self.getToken(APIParser.COMPARE_SKIPLINE, 0)

        def COMPARE_NOSKIPLINE(self):
            return self.getToken(APIParser.COMPARE_NOSKIPLINE, 0)

        def COMPARE_LCS(self):
            return self.getToken(APIParser.COMPARE_LCS, 0)

        def COMPARE_MYERS(self):
            return self.getToken(APIParser.COMPARE_MYERS, 0)

        def COMPARE_WORK(self):
            return self.getToken(APIParser.COMPARE_WORK, 0)

        def COMPARE_REFERENCE(self):
            return self.getToken(APIParser.COMPARE_REFERENCE, 0)

        def COMPARE_MASK(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_MASK)
            else:
                return self.getToken(APIParser.COMPARE_MASK, i)

        def COMPARE_NOMASK(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_NOMASK)
            else:
                return self.getToken(APIParser.COMPARE_NOMASK, i)

        def COMPARE_CASE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_CASE)
            else:
                return self.getToken(APIParser.COMPARE_CASE, i)

        def COMPARE_NOCASE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_NOCASE)
            else:
                return self.getToken(APIParser.COMPARE_NOCASE, i)

        def COMPARE_IGBLANK(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_IGBLANK)
            else:
                return self.getToken(APIParser.COMPARE_IGBLANK, i)

        def COMPARE_NOIGBLANK(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_NOIGBLANK)
            else:
                return self.getToken(APIParser.COMPARE_NOIGBLANK, i)

        def COMPARE_TRIM(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_TRIM)
            else:
                return self.getToken(APIParser.COMPARE_TRIM, i)

        def COMPARE_NOTRIM(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_NOTRIM)
            else:
                return self.getToken(APIParser.COMPARE_NOTRIM, i)

        def COMPARE_CONSOLE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_CONSOLE)
            else:
                return self.getToken(APIParser.COMPARE_CONSOLE, i)

        def COMPARE_DIFFFILE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.COMPARE_DIFFFILE)
            else:
                return self.getToken(APIParser.COMPARE_DIFFFILE, i)

        def getRuleIndex(self):
            return APIParser.RULE_compare

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCompare" ):
                return visitor.visitCompare(self)
            else:
                return visitor.visitChildren(self)




    def compare(self):

        localctx = APIParser.CompareContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_compare)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 477
            self.match(APIParser.COMPARE)
            self.state = 516
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,66,self._ctx)
            if la_ == 1:
                self.state = 478
                self.match(APIParser.COMPARE_EXPRESSION)
                self.state = 479
                self.match(APIParser.COMPARE_EXPRESSION)
                self.state = 483
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la - 171)) & ~0x3f) == 0 and ((1 << (_la - 171)) & 1011) != 0:
                    self.state = 480
                    _la = self._input.LA(1)
                    if not((((_la - 171)) & ~0x3f) == 0 and ((1 << (_la - 171)) & 1011) != 0):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 485
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass

            elif la_ == 2:
                self.state = 486
                _la = self._input.LA(1)
                if not(_la==184 or _la==185):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 487
                self.match(APIParser.COMPARE_EXPRESSION)
                pass

            elif la_ == 3:
                self.state = 488
                self.match(APIParser.COMPARE_MASKLINE)
                self.state = 489
                self.match(APIParser.COMPARE_EXPRESSION)
                self.state = 490
                self.match(APIParser.COMPARE_EQUAL)
                self.state = 491
                self.match(APIParser.COMPARE_EXPRESSION)
                pass

            elif la_ == 4:
                self.state = 492
                self.match(APIParser.COMPARE_NOMASKLINE)
                self.state = 493
                self.match(APIParser.COMPARE_EXPRESSION)
                pass

            elif la_ == 5:
                self.state = 494
                self.match(APIParser.COMPARE_RESET)
                pass

            elif la_ == 6:
                self.state = 495
                self.match(APIParser.COMPARE_SET)
                self.state = 499
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la - 171)) & ~0x3f) == 0 and ((1 << (_la - 171)) & 1011) != 0:
                    self.state = 496
                    _la = self._input.LA(1)
                    if not((((_la - 171)) & ~0x3f) == 0 and ((1 << (_la - 171)) & 1011) != 0):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 501
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass

            elif la_ == 7:
                self.state = 502
                self.match(APIParser.COMPARE_SET)
                self.state = 503
                self.match(APIParser.COMPARE_OUTPUT)
                self.state = 505 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 504
                    _la = self._input.LA(1)
                    if not(_la==182 or _la==183):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 507 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==182 or _la==183):
                        break

                pass

            elif la_ == 8:
                self.state = 509
                self.match(APIParser.COMPARE_SET)
                self.state = 510
                self.match(APIParser.COMPARE_ALGORITHM)
                self.state = 511
                _la = self._input.LA(1)
                if not(_la==191 or _la==192):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass

            elif la_ == 9:
                self.state = 512
                self.match(APIParser.COMPARE_SET)
                self.state = 513
                _la = self._input.LA(1)
                if not(_la==189 or _la==190):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 514
                self.match(APIParser.COMPARE_ENCODING)
                self.state = 515
                self.match(APIParser.COMPARE_EXPRESSION)
                pass


            self.state = 519
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==166:
                self.state = 518
                self.match(APIParser.COMPARE_SEMICOLON)


            self.state = 522
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 521
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class DataContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DATA(self):
            return self.getToken(APIParser.DATA, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def DATA_SET(self):
            return self.getToken(APIParser.DATA_SET, 0)

        def DATA_SEEDFILE(self):
            return self.getToken(APIParser.DATA_SEEDFILE, 0)

        def DATA_DIR(self):
            return self.getToken(APIParser.DATA_DIR, 0)

        def DATA_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.DATA_EXPRESSION)
            else:
                return self.getToken(APIParser.DATA_EXPRESSION, i)

        def DATA_CREATE(self):
            return self.getToken(APIParser.DATA_CREATE, 0)

        def DATA_FILETYPE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.DATA_FILETYPE)
            else:
                return self.getToken(APIParser.DATA_FILETYPE, i)

        def DATA_FILE(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.DATA_FILE)
            else:
                return self.getToken(APIParser.DATA_FILE, i)

        def DATACOLUMN_OPEN(self):
            return self.getToken(APIParser.DATACOLUMN_OPEN, 0)

        def DATA_CONVERT(self):
            return self.getToken(APIParser.DATA_CONVERT, 0)

        def DATA_TO(self):
            return self.getToken(APIParser.DATA_TO, 0)

        def DATA_SEMICOLON(self):
            return self.getToken(APIParser.DATA_SEMICOLON, 0)

        def DATACOLUMN_CONTENT(self):
            return self.getToken(APIParser.DATACOLUMN_CONTENT, 0)

        def DATA_ROWS(self):
            return self.getToken(APIParser.DATA_ROWS, 0)

        def DATA_INT(self):
            return self.getToken(APIParser.DATA_INT, 0)

        def getRuleIndex(self):
            return APIParser.RULE_data

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitData" ):
                return visitor.visitData(self)
            else:
                return visitor.visitChildren(self)




    def data(self):

        localctx = APIParser.DataContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_data)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 524
            self.match(APIParser.DATA)
            self.state = 556
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [196]:
                self.state = 525
                self.match(APIParser.DATA_SET)
                self.state = 526
                self.match(APIParser.DATA_SEEDFILE)
                self.state = 527
                self.match(APIParser.DATA_DIR)
                self.state = 528
                self.match(APIParser.DATA_EXPRESSION)
                self.state = 530
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==195:
                    self.state = 529
                    self.match(APIParser.DATA_SEMICOLON)


                pass
            elif token in [199]:
                self.state = 532
                self.match(APIParser.DATA_CREATE)
                self.state = 533
                self.match(APIParser.DATA_FILETYPE)
                self.state = 534
                self.match(APIParser.DATA_FILE)
                self.state = 535
                self.match(APIParser.DATA_EXPRESSION)
                self.state = 536
                self.match(APIParser.DATACOLUMN_OPEN)
                self.state = 538
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==211:
                    self.state = 537
                    self.match(APIParser.DATACOLUMN_CONTENT)


                self.state = 542
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==202:
                    self.state = 540
                    self.match(APIParser.DATA_ROWS)
                    self.state = 541
                    self.match(APIParser.DATA_INT)


                self.state = 544
                self.match(APIParser.DATA_SEMICOLON)
                pass
            elif token in [206]:
                self.state = 545
                self.match(APIParser.DATA_CONVERT)
                self.state = 546
                self.match(APIParser.DATA_FILETYPE)
                self.state = 547
                self.match(APIParser.DATA_FILE)
                self.state = 548
                self.match(APIParser.DATA_EXPRESSION)
                self.state = 549
                self.match(APIParser.DATA_TO)
                self.state = 550
                self.match(APIParser.DATA_FILETYPE)
                self.state = 551
                self.match(APIParser.DATA_FILE)
                self.state = 552
                self.match(APIParser.DATA_EXPRESSION)
                self.state = 554
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==195:
                    self.state = 553
                    self.match(APIParser.DATA_SEMICOLON)


                pass
            else:
                raise NoViableAltException(self)

            self.state = 559
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 558
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HelpContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HELP(self):
            return self.getToken(APIParser.HELP, 0)

        def HELP_COMMAND(self):
            return self.getToken(APIParser.HELP_COMMAND, 0)

        def HELP_SEMICOLON(self):
            return self.getToken(APIParser.HELP_SEMICOLON, 0)

        def CRLF(self):
            return self.getToken(APIParser.CRLF, 0)

        def getRuleIndex(self):
            return APIParser.RULE_help

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHelp" ):
                return visitor.visitHelp(self)
            else:
                return visitor.visitChildren(self)




    def help_(self):

        localctx = APIParser.HelpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_help)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 561
            self.match(APIParser.HELP)
            self.state = 563
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==213:
                self.state = 562
                self.match(APIParser.HELP_COMMAND)


            self.state = 566
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==215:
                self.state = 565
                self.match(APIParser.HELP_SEMICOLON)


            self.state = 569
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==4:
                self.state = 568
                self.match(APIParser.CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class MonitorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def MONITOR(self):
            return self.getToken(APIParser.MONITOR, 0)

        def MONITOR_SEMICOLON(self):
            return self.getToken(APIParser.MONITOR_SEMICOLON, 0)

        def MONITOR_CRLF(self):
            return self.getToken(APIParser.MONITOR_CRLF, 0)

        def MONITOR_MANAGER(self):
            return self.getToken(APIParser.MONITOR_MANAGER, 0)

        def MONITOR_ON(self):
            return self.getToken(APIParser.MONITOR_ON, 0)

        def MONITOR_OFF(self):
            return self.getToken(APIParser.MONITOR_OFF, 0)

        def MONITOR_CREATE(self):
            return self.getToken(APIParser.MONITOR_CREATE, 0)

        def MONITOR_TASK(self):
            return self.getToken(APIParser.MONITOR_TASK, 0)

        def MONITOR_START(self):
            return self.getToken(APIParser.MONITOR_START, 0)

        def MONITOR_EXPRESSION(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.MONITOR_EXPRESSION)
            else:
                return self.getToken(APIParser.MONITOR_EXPRESSION, i)

        def MONITOR_STOP(self):
            return self.getToken(APIParser.MONITOR_STOP, 0)

        def MONITOR_REPORT(self):
            return self.getToken(APIParser.MONITOR_REPORT, 0)

        def MONITOR_LIST(self):
            return self.getToken(APIParser.MONITOR_LIST, 0)

        def MONITOR_WORKERS(self):
            return self.getToken(APIParser.MONITOR_WORKERS, 0)

        def MONITOR_EQUAL(self, i:int=None):
            if i is None:
                return self.getTokens(APIParser.MONITOR_EQUAL)
            else:
                return self.getToken(APIParser.MONITOR_EQUAL, i)

        def getRuleIndex(self):
            return APIParser.RULE_monitor

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitMonitor" ):
                return visitor.visitMonitor(self)
            else:
                return visitor.visitChildren(self)




    def monitor(self):

        localctx = APIParser.MonitorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_monitor)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 571
            self.match(APIParser.MONITOR)
            self.state = 603
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,81,self._ctx)
            if la_ == 1:
                self.state = 572
                self.match(APIParser.MONITOR_MANAGER)
                self.state = 573
                self.match(APIParser.MONITOR_ON)
                self.state = 576
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==218:
                    self.state = 574
                    self.match(APIParser.MONITOR_WORKERS)
                    self.state = 575
                    self.match(APIParser.MONITOR_EXPRESSION)


                pass

            elif la_ == 2:
                self.state = 578
                self.match(APIParser.MONITOR_MANAGER)
                self.state = 579
                self.match(APIParser.MONITOR_OFF)
                pass

            elif la_ == 3:
                self.state = 580
                self.match(APIParser.MONITOR_CREATE)
                self.state = 581
                self.match(APIParser.MONITOR_TASK)

                self.state = 583
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,79,self._ctx)
                if la_ == 1:
                    self.state = 582
                    self.match(APIParser.MONITOR_EXPRESSION)


                self.state = 588 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 585
                    self.match(APIParser.MONITOR_EXPRESSION)
                    self.state = 586
                    self.match(APIParser.MONITOR_EQUAL)
                    self.state = 587
                    self.match(APIParser.MONITOR_EXPRESSION)
                    self.state = 590 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==228):
                        break

                pass

            elif la_ == 4:
                self.state = 592
                self.match(APIParser.MONITOR_START)
                self.state = 593
                self.match(APIParser.MONITOR_TASK)
                self.state = 594
                self.match(APIParser.MONITOR_EXPRESSION)
                pass

            elif la_ == 5:
                self.state = 595
                self.match(APIParser.MONITOR_STOP)
                self.state = 596
                self.match(APIParser.MONITOR_TASK)
                self.state = 597
                self.match(APIParser.MONITOR_EXPRESSION)
                pass

            elif la_ == 6:
                self.state = 598
                self.match(APIParser.MONITOR_REPORT)
                self.state = 599
                self.match(APIParser.MONITOR_TASK)
                self.state = 600
                self.match(APIParser.MONITOR_EXPRESSION)
                pass

            elif la_ == 7:
                self.state = 601
                self.match(APIParser.MONITOR_LIST)
                self.state = 602
                self.match(APIParser.MONITOR_TASK)
                pass


            self.state = 606
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==230:
                self.state = 605
                self.match(APIParser.MONITOR_SEMICOLON)


            self.state = 609
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==229:
                self.state = 608
                self.match(APIParser.MONITOR_CRLF)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx





